<?php

/**
 * Created by PhpStorm.
 * User: trusakov
 * Date: 24.01.15
 * Time: 17:01
 */
class Dentalex_Orders_Model_Sales_Quote extends Mage_Sales_Model_Quote
{
    public function isVirtual()
    {
        return true;
    }

    public function removeItem($itemId)
    {
        $item = $this->getItemById($itemId);

        if ($groupedId = $item->grouped_id) {
            foreach ($this->getAllItems() as $quoteItem) {
                if ($quoteItem->grouped_id == $groupedId) {
                    parent::removeItem($quoteItem->getId());
                }
            }
        } else {
            parent::removeItem($item->getId());
        }
        return $this;
    }


    protected function _addCatalogProduct(Mage_Catalog_Model_Product $product, $qty = 1, $groupedId = null)
    {
        $newItem = false;
        $item = $this->getItemByProduct($product);
        if (!$item) {
            $item = Mage::getModel('sales/quote_item');
            $item->setQuote($this);
            if (Mage::app()->getStore()->isAdmin()) {
                $item->setStoreId($this->getStore()->getId());
            } else {
                $item->setStoreId(Mage::app()->getStore()->getId());
            }
            $newItem = true;
        }
        if ($groupedId)
            $item->setData('grouped_id', $groupedId);

        /**
         * We can't modify existing child items
         */
        if ($item->getId() && $product->getParentProductId()) {
            return $item;
        }

        $item->setOptions($product->getCustomOptions())
            ->setProduct($product);

        // Add only item that is not in quote already (there can be other new or already saved item
        if ($newItem) {
            $this->addItem($item);
        }

        return $item;
    }

    public function addProductAdvanced(Mage_Catalog_Model_Product $product, $request = null, $processMode = null)
    {

        if($product->only_in_group){
            throw new Mage_Core_Exception('You can bay this product only in group');
        }
        if ($request === null) {
            $request = 1;
        }
        if (is_numeric($request)) {
            $request = new Varien_Object(array('qty' => $request));
        }
        if (!($request instanceof Varien_Object)) {
            Mage::throwException(Mage::helper('sales')->__('Invalid request for adding product to quote.'));
        }

        $cartCandidates = $product->getTypeInstance(true)
            ->prepareForCartAdvanced($request, $product, $processMode);

        /**
         * Error message
         */
        if (is_string($cartCandidates)) {
            return $cartCandidates;
        }

        /**
         * If prepare process return one object
         */
        if (!is_array($cartCandidates)) {
            $cartCandidates = array($cartCandidates);
        }

        $parentItem = null;
        $errors = array();
        $items = array();
        $groupedId = ($product->getTypeId() == 'grouped') ? $product->getId() : null;
        foreach ($cartCandidates as $candidate) {
            // Child items can be sticked together only within their parent
            $stickWithinParent = $candidate->getParentProductId() ? $parentItem : null;
            $candidate->setStickWithinParent($stickWithinParent);
            $item = $this->_addCatalogProduct($candidate, $candidate->getCartQty(), $groupedId);
            if ($request->getResetCount() && !$stickWithinParent && $item->getId() === $request->getId()) {
                $item->setData('qty', 0);
            }
            $items[] = $item;

            /**
             * As parent item we should always use the item of first added product
             */
            if (!$parentItem) {
                $parentItem = $item;
            }
            if ($parentItem && $candidate->getParentProductId()) {
                $item->setParentItem($parentItem);
            }

            /**
             * We specify qty after we know about parent (for stock)
             */
            $item->addQty($candidate->getCartQty());

            // collect errors instead of throwing first one
            if ($item->getHasError()) {
                $message = $item->getMessage();
                if (!in_array($message, $errors)) { // filter duplicate messages
                    $errors[] = $message;
                }
            }
        }
        if (!empty($errors)) {
            Mage::throwException(implode("\n", $errors));
        }

        Mage::dispatchEvent('sales_quote_product_add_after', array('items' => $items));

        return $item;
    }
}