<?php
/**
 * Dentalex_Speakers extension
 * 
 * NOTICE OF LICENSE
 * 
 * This source file is subject to the MIT License
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/mit-license.php
 * 
 * @category       Dentalex
 * @package        Dentalex_Speakers
 * @copyright      Copyright (c) 2014
 * @license        http://opensource.org/licenses/mit-license.php MIT License
 */
/**
 * Speaker tab on product edit form
 *
 * @category    Dentalex
 * @package     Dentalex_Speakers
 * @author      Ultimate Module Creator
 */
class Dentalex_Speakers_Block_Adminhtml_Catalog_Product_Edit_Tab_Speaker
    extends Mage_Adminhtml_Block_Widget_Grid {
    /**
     * Set grid params
     * @access public
     * @author Ultimate Module Creator
     */
    public function __construct() {
        parent::__construct();
        $this->setId('speaker_grid');
        $this->setDefaultSort('position');
        $this->setDefaultDir('ASC');
        $this->setUseAjax(true);
//        if ($this->getProduct()->getId()) {
//            $this->setDefaultFilter(array('in_speakers'=>2));
//        }
    }

    public function getMainButtonsHtml()
    {
        $html = parent::getMainButtonsHtml();//get the parent class buttons

        $url = $this->getUrl('*/speakers_speaker/new',array('popup' => 1));

        $addButton = $this->getLayout()->createBlock('adminhtml/widget_button') //create the add button
            ->setData(array(
                'label'     => Mage::helper('adminhtml')->__('Add speaker'),
                'onclick'   => "speaker_gridJsObject.create('$url')",
                'class'   => 'task add',
                'id' => 'add_speaker'
            ))->toHtml();
        return $html.$addButton;
    }

    /**
     * prepare the speaker collection
     * @access protected
     * @return Dentalex_Speakers_Block_Adminhtml_Catalog_Product_Edit_Tab_Speaker
     * @author Ultimate Module Creator
     */
    protected function _prepareCollection() {
        $collection = Mage::getResourceModel('dentalex_speakers/speaker_collection')
            ->addAttributeToSelect('fullname')
            ->addAttributeToSelect('email');

//        $userId = Mage::getSingleton('admin/session')->getUser()->getId();
//
//        $role = strtolower(Mage::getModel('admin/user')->load($userId)->getRole()->getData('role_name'));
//
//        if($role !== 'administrators'){
//            $collection->addAttributeToFilter('created_by', array('eq' => $userId));
//        }
        if ($this->getProduct()->getId()){
            $constraint = 'related.product_id='.$this->getProduct()->getId();
            }
            else{
                $constraint = 'related.product_id=0';
            }
        $collection->getSelect()->joinLeft(
            array('related'=>$collection->getTable('dentalex_speakers/speaker_product')),
            'related.speaker_id=e.entity_id AND '.$constraint,
            array('position')
        );
        $this->setCollection($collection);
        parent::_prepareCollection();
        return $this;
    }
    /**
     * prepare mass action grid
     * @access protected
     * @return Dentalex_Speakers_Block_Adminhtml_Catalog_Product_Edit_Tab_Speaker
     * @author Ultimate Module Creator
     */
    protected function _prepareMassaction(){
        return $this;
    }
    /**
     * prepare the grid columns
     * @access protected
     * @return Dentalex_Speakers_Block_Adminhtml_Catalog_Product_Edit_Tab_Speaker
     * @author Ultimate Module Creator
     */
    protected function _prepareColumns(){
        $this->addColumn('in_speakers', array(
            'header_css_class'  => 'a-center',
            'type'  => 'checkbox',
            'name'  => 'in_speakers',
            'values'=> $this->_getSelectedSpeakers(),
            'align' => 'center',
            'index' => 'entity_id'
        ));
        $this->addColumn('fullname', array(
            'header'=> Mage::helper('dentalex_speakers')->__('Fullname'),
            'align' => 'left',
            'index' => 'fullname',
            'renderer'  => 'dentalex_speakers/adminhtml_helper_column_renderer_relation',
            'params' => array(
                'id'=>'getId'
            ),
            'base_link' => 'adminhtml/speakers_speaker/edit',
        ));
        $this->addColumn('email', array(
            'header'=> Mage::helper('dentalex_speakers')->__('Email'),
            'align' => 'left',
            'index' => 'email',
            'renderer'  => 'dentalex_speakers/adminhtml_helper_column_renderer_relation',
            'params' => array(
                'id'=>'getId'
            ),
            'base_link' => 'adminhtml/speakers_speaker/edit',
        ));
        $this->addColumn('position', array(
            'header'        => Mage::helper('dentalex_speakers')->__('Position'),
            'name'          => 'position',
            'width'         => 60,
            'type'        => 'number',
            'validate_class'=> 'validate-number',
            'index'         => 'position',
            'editable'      => true,
        ));
        return parent::_prepareColumns();
    }
    /**
     * Retrieve selected speakers
     * @access protected
     * @return array
     * @author Ultimate Module Creator
     */
    protected function _getSelectedSpeakers(){
        $speakers = $this->getProductSpeakers();
        if (!is_array($speakers)) {
            $speakers = array_keys($this->getSelectedSpeakers());
        }
        return $speakers;
    }
     /**
     * Retrieve selected speakers
     * @access protected
     * @return array
     * @author Ultimate Module Creator
     */
    public function getSelectedSpeakers() {
        $speakers = array();
        //used helper here in order not to override the product model
        $selected = Mage::helper('dentalex_speakers/product')->getSelectedSpeakers(Mage::registry('current_product'));
        if (!is_array($selected)){
            $selected = array();
        }
        foreach ($selected as $speaker) {
            $speakers[$speaker->getId()] = array('position' => $speaker->getPosition());
        }
        return $speakers;
    }
    /**
     * get row url
     * @access public
     * @param Dentalex_Speakers_Model_Speaker
     * @return string
     * @author Ultimate Module Creator
     */
    public function getRowUrl($item){
        return '#';
    }
    /**
     * get grid url
     * @access public
     * @return string
     * @author Ultimate Module Creator
     */
    public function getGridUrl(){
        return $this->getUrl('*/*/speakersGrid', array(
            'id'=>$this->getProduct()->getId()
        ));
    }
    /**
     * get the current product
     * @access public
     * @return Mage_Catalog_Model_Product
     * @author Ultimate Module Creator
     */
    public function getProduct(){
        return Mage::registry('current_product');
    }
    /**
     * Add filter
     * @access protected
     * @param object $column
     * @return Dentalex_Speakers_Block_Adminhtml_Catalog_Product_Edit_Tab_Speaker
     * @author Ultimate Module Creator
     */
    protected function _addColumnFilterToCollection($column){
        if ($column->getId() == 'in_speakers') {
            $speakerIds = $this->_getSelectedSpeakers();
            if (empty($speakerIds)) {
                $speakerIds = 0;
            }
            if ($column->getFilter()->getValue()) {
                $this->getCollection()->addFieldToFilter('entity_id', array('in'=>$speakerIds));
            }
            else {
                if($speakerIds) {
                    $this->getCollection()->addFieldToFilter('entity_id', array('nin'=>$speakerIds));
                }
            }
        }
        else {
            parent::_addColumnFilterToCollection($column);
        }
        return $this;
    }
}
