<?php
/**
 * Dentalex_Speakers extension
 * 
 * NOTICE OF LICENSE
 * 
 * This source file is subject to the MIT License
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/mit-license.php
 * 
 * @category       Dentalex
 * @package        Dentalex_Speakers
 * @copyright      Copyright (c) 2014
 * @license        http://opensource.org/licenses/mit-license.php MIT License
 */
/**
 * Speaker comment edit form tab
 *
 * @category    Dentalex
 * @package     Dentalex_Speakers
 * @author      Ultimate Module Creator
 */
class Dentalex_Speakers_Block_Adminhtml_Speaker_Comment_Edit_Tab_Form
    extends Mage_Adminhtml_Block_Widget_Form {
    /**
     * prepare the form
     * @access protected
     * @return Speakers_Speaker_Block_Adminhtml_Speaker_Comment_Edit_Tab_Form
     * @author Ultimate Module Creator
     */
    protected function _prepareForm(){
        $speaker = Mage::registry('current_speaker');
        $comment    = Mage::registry('current_comment');
        $form = new Varien_Data_Form();
        $form->setHtmlIdPrefix('comment_');
        $form->setFieldNameSuffix('comment');
        $this->setForm($form);
        $fieldset = $form->addFieldset('comment_form', array('legend'=>Mage::helper('dentalex_speakers')->__('Comment')));
        $fieldset->addField('speaker_id', 'hidden', array(
            'name'  => 'speaker_id',
            'after_element_html' => '<a href="'.Mage::helper('adminhtml')->getUrl('adminhtml/speakers_speaker/edit', array('id'=>$speaker->getId())).'" target="_blank">'.Mage::helper('dentalex_speakers')->__('Speaker').' : '.$speaker->getFullname().'</a>'
        ));
        $fieldset->addField('title', 'text', array(
            'label' => Mage::helper('dentalex_speakers')->__('Title'),
            'name'  => 'title',
            'required'  => true,
            'class' => 'required-entry',
        ));
        $fieldset->addField('comment', 'textarea', array(
            'label' => Mage::helper('dentalex_speakers')->__('Comment'),
            'name'  => 'comment',
            'required'  => true,
            'class' => 'required-entry',
        ));
        $fieldset->addField('status', 'select', array(
            'label' => Mage::helper('dentalex_speakers')->__('Status'),
            'name'  => 'status',
            'required'  => true,
            'class' => 'required-entry',
            'values'=> array(
                array(
                    'value' => Dentalex_Speakers_Model_Speaker_Comment::STATUS_PENDING,
                    'label' => Mage::helper('dentalex_speakers')->__('Pending'),
                ),
                array(
                    'value' => Dentalex_Speakers_Model_Speaker_Comment::STATUS_APPROVED,
                    'label' => Mage::helper('dentalex_speakers')->__('Approved'),
                ),
                array(
                    'value' => Dentalex_Speakers_Model_Speaker_Comment::STATUS_REJECTED,
                    'label' => Mage::helper('dentalex_speakers')->__('Rejected'),
                ),
            ),
        ));
        $configuration = array(
             'label' => Mage::helper('dentalex_speakers')->__('Poster name'),
             'name'  => 'name',
             'required'  => true,
             'class' => 'required-entry',
        );
        if ($comment->getCustomerId()) {
            $configuration['after_element_html'] = '<a href="'.Mage::helper('adminhtml')->getUrl('adminhtml/customer/edit', array('id'=>$comment->getCustomerId())).'" target="_blank">'.Mage::helper('dentalex_speakers')->__('Customer profile').'</a>';
        }
        $fieldset->addField('name', 'text', $configuration);
        $fieldset->addField('email', 'text', array(
            'label' => Mage::helper('dentalex_speakers')->__('Poster e-mail'),
            'name'  => 'email',
            'required'  => true,
            'class' => 'required-entry',
        ));
        $fieldset->addField('customer_id', 'hidden', array(
            'name'  => 'customer_id',
        ));

        if (Mage::app()->isSingleStoreMode()){
            $fieldset->addField('store_id', 'hidden', array(
                'name'      => 'stores[]',
                'value'     => Mage::app()->getStore(true)->getId()
            ));
            Mage::registry('current_comment')->setStoreId(Mage::app()->getStore(true)->getId());
        }
        $form->addValues($this->getComment()->getData());
        return parent::_prepareForm();
    }
    /**
     * get the current comment
     * @access public
     * @return Dentalex_Speakers_Model_Speaker_Comment
     */
    public function getComment(){
        return Mage::registry('current_comment');
    }
}