<?php
 /**
 * Dentalex_Speakers extension
 * 
 * NOTICE OF LICENSE
 * 
 * This source file is subject to the MIT License
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/mit-license.php
 * 
 * @category       Dentalex
 * @package        Dentalex_Speakers
 * @copyright      Copyright (c) 2014
 * @license        http://opensource.org/licenses/mit-license.php MIT License
 */
/**
 * Speaker admin edit tab attributes block
 * @category    Dentalex
 * @package     Dentalex_Speakers
 * @author      Ultimate Module Creator
*/
class Dentalex_Speakers_Block_Adminhtml_Speaker_Edit_Tab_Attributes
    extends Mage_Adminhtml_Block_Widget_Form {
    /**
     * prepare the attributes for the form
     * @access protected
     * @return void
     * @see Mage_Adminhtml_Block_Widget_Form::_prepareForm()
     * @author Ultimate Module Creator
     */
    protected function _prepareForm() {
        /** @var  $speaker Dentalex_Speakers_Model_Speaker */
        $speaker = Mage::registry('current_speaker');

        $form = new Varien_Data_Form();
        $form->setDataObject(Mage::registry('current_speaker'));
        $fieldset = $form->addFieldset('info',
            array(
                'legend'=>Mage::helper('dentalex_speakers')->__('Speaker Information'),
                 'class'=>'fieldset-wide',
            )
        );
        $attributes = $this->getAttributes();
        foreach ($attributes as $attribute){
            if(in_array($attribute->attribute_code,array('fullname','url_key','customer_id')))
                $attribute->is_visible = 0;
            $attribute->setEntity(Mage::getResourceModel('dentalex_speakers/speaker'));
        }
        $this->_setFieldset($attributes, $fieldset, array());
        $formValues = Mage::registry('current_speaker')->getData();
        if (!Mage::registry('current_speaker')->getId()) {
            foreach ($attributes as $attribute) {
                if (!isset($formValues[$attribute->getAttributeCode()])) {
                    $formValues[$attribute->getAttributeCode()] = $attribute->getDefaultValue();
                }
            }
        }

        // Add password management fieldset
        $newFieldset = $form->addFieldset(
            'password_fieldset',
            array('legend' => Mage::helper('customer')->__('Password Management'))
        );
        if ($speaker->getId()) {
                // New customer password
                $field = $newFieldset->addField('new_password', 'text',
                    array(
                        'label' => Mage::helper('customer')->__('New Password'),
                        'name'  => 'new_password',
                        'class' => 'validate-new-password'
                    )
                );
                $field->setRenderer($this->getLayout()->createBlock('adminhtml/customer_edit_renderer_newpass'));

        } else {
            $field = $newFieldset->addField('password', 'text',
                array(
                    'label' => Mage::helper('customer')->__('Password'),
                    'class' => 'input-text required-entry validate-password',
                    'name'  => 'password',
                    'required' => true
                )
            );
            $field->setRenderer($this->getLayout()->createBlock('adminhtml/customer_edit_renderer_newpass'));
        }

        $form->addValues($formValues);
        $form->setFieldNameSuffix('speaker');
        $this->setForm($form);
    }
    /**
     * prepare layout
     * @access protected
     * @return void
     * @see Mage_Adminhtml_Block_Widget_Form::_prepareLayout()
     * @author Ultimate Module Creator
     */
    protected function _prepareLayout() {
        Varien_Data_Form::setElementRenderer(
            $this->getLayout()->createBlock('adminhtml/widget_form_renderer_element')
        );
        Varien_Data_Form::setFieldsetRenderer(
            $this->getLayout()->createBlock('adminhtml/widget_form_renderer_fieldset')
        );
        Varien_Data_Form::setFieldsetElementRenderer(
            $this->getLayout()->createBlock('dentalex_speakers/adminhtml_speakers_renderer_fieldset_element')
        );
    }
    /**
     * get the additional element types for form
     * @access protected
     * @return array()
     * @see Mage_Adminhtml_Block_Widget_Form::_getAdditionalElementTypes()
     * @author Ultimate Module Creator
     */
    protected function _getAdditionalElementTypes(){
        return array(
            'file'    => Mage::getConfig()->getBlockClassName('dentalex_speakers/adminhtml_speaker_helper_file'),
            'image' => Mage::getConfig()->getBlockClassName('dentalex_speakers/adminhtml_speaker_helper_image'),
            'textarea' => Mage::getConfig()->getBlockClassName('adminhtml/catalog_helper_form_wysiwyg')
        );
    }
    /**
     * get current entity
     * @access protected
     * @return Dentalex_Speakers_Model_Speaker
     * @author Ultimate Module Creator
     */
    public function getSpeaker() {
        return Mage::registry('current_speaker');
    }

}
