<?php
/**
 * Dentalex_Speakers extension
 * 
 * NOTICE OF LICENSE
 * 
 * This source file is subject to the MIT License
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/mit-license.php
 * 
 * @category       Dentalex
 * @package        Dentalex_Speakers
 * @copyright      Copyright (c) 2014
 * @license        http://opensource.org/licenses/mit-license.php MIT License
 */
/**
 * Speaker admin grid block
 *
 * @category    Dentalex
 * @package     Dentalex_Speakers
 * @author      Ultimate Module Creator
 */
class Dentalex_Speakers_Block_Adminhtml_Speaker_Grid
    extends Mage_Adminhtml_Block_Widget_Grid {
    /**
     * constructor
     * @access public
     * @author Ultimate Module Creator
     */
    public function __construct(){
        parent::__construct();
        $this->setId('speakerGrid');
        $this->setDefaultSort('entity_id');
        $this->setDefaultDir('ASC');
        $this->setSaveParametersInSession(true);
        $this->setUseAjax(true);
    }
    /**
     * prepare collection
     * @access protected
     * @return Dentalex_Speakers_Block_Adminhtml_Speaker_Grid
     * @author Ultimate Module Creator
     */
    protected function _prepareCollection(){
        $collection = Mage::getModel('dentalex_speakers/speaker')->getCollection()
            ->addAttributeToSelect('email')
            ->addAttributeToSelect('medical_degree')
            ->addAttributeToSelect('status');
        $adminStore = Mage_Core_Model_App::ADMIN_STORE_ID;
        $store = $this->_getStore();
        $collection->joinAttribute('fullname', 'dentalex_speakers_speaker/fullname', 'entity_id', null, 'inner', $adminStore);
        if ($store->getId()) {
            $collection->joinAttribute('dentalex_speakers_speaker_fullname', 'dentalex_speakers_speaker/fullname', 'entity_id', null, 'inner', $store->getId());
        }
        $userId = Mage::getSingleton('admin/session')->getUser()->getId();

        $role = strtolower(Mage::getModel('admin/user')->load($userId)->getRole()->getData('role_name'));

        if($role !== 'administrators'){
            $collection->addAttributeToFilter('created_by', array('eq' => $userId));
        }

        $this->setCollection($collection);
        return parent::_prepareCollection();
    }
    /**
     * prepare grid collection
     * @access protected
     * @return Dentalex_Speakers_Block_Adminhtml_Speaker_Grid
     * @author Ultimate Module Creator
     */
    protected function _prepareColumns(){
        $this->addColumn('entity_id', array(
            'header'    => Mage::helper('dentalex_speakers')->__('Id'),
            'index'        => 'entity_id',
            'type'        => 'number'
        ));
        $this->addColumn('fullname', array(
            'header'    => Mage::helper('dentalex_speakers')->__('Fullname'),
            'align'     => 'left',
            'index'     => 'fullname',
        ));
        if ($this->_getStore()->getId()){
            $this->addColumn('dentalex_speakers_speaker_fullname', array(
                'header'    => Mage::helper('dentalex_speakers')->__('Fullname in %s', $this->_getStore()->getName()),
                'align'     => 'left',
                'index'     => 'dentalex_speakers_speaker_fullname',
            ));
        }

        $this->addColumn('status', array(
            'header'    => Mage::helper('dentalex_speakers')->__('Status'),
            'index'        => 'status',
            'type'        => 'options',
            'options'    => array(
                '1' => Mage::helper('dentalex_speakers')->__('Enabled'),
                '0' => Mage::helper('dentalex_speakers')->__('Disabled'),
            )
        ));
        $this->addColumn('email', array(
            'header'=> Mage::helper('dentalex_speakers')->__('Email'),
            'index' => 'email',
            'type'=> 'text',

        ));
        $this->addColumn('medical_degree', array(
            'header'=> Mage::helper('dentalex_speakers')->__('Medical degree'),
            'index' => 'medical_degree',
            'type'=> 'text',

        ));

        $this->addColumn('action',
            array(
                'header'=>  Mage::helper('dentalex_speakers')->__('Action'),
                'width' => '100',
                'type'  => 'action',
                'getter'=> 'getId',
                'actions'   => array(
                    array(
                        'caption'   => Mage::helper('dentalex_speakers')->__('Edit'),
                        'url'   => array('base'=> '*/*/edit'),
                        'field' => 'id'
                    )
                ),
                'filter'=> false,
                'is_system'    => true,
                'sortable'  => false,
        ));
        $this->addExportType('*/*/exportCsv', Mage::helper('dentalex_speakers')->__('CSV'));
        $this->addExportType('*/*/exportExcel', Mage::helper('dentalex_speakers')->__('Excel'));
        $this->addExportType('*/*/exportXml', Mage::helper('dentalex_speakers')->__('XML'));
        return parent::_prepareColumns();
    }
    /**
     * get the selected store
     * @access protected
     * @return Mage_Core_Model_Store
     * @author Ultimate Module Creator
     */
    protected function _getStore(){
        $storeId = (int) $this->getRequest()->getParam('store', 0);
        return Mage::app()->getStore($storeId);
    }
    /**
     * prepare mass action
     * @access protected
     * @return Dentalex_Speakers_Block_Adminhtml_Speaker_Grid
     * @author Ultimate Module Creator
     */
    protected function _prepareMassaction(){
        $this->setMassactionIdField('entity_id');
        $this->getMassactionBlock()->setFormFieldName('speaker');
        $this->getMassactionBlock()->addItem('delete', array(
            'label'=> Mage::helper('dentalex_speakers')->__('Delete'),
            'url'  => $this->getUrl('*/*/massDelete'),
            'confirm'  => Mage::helper('dentalex_speakers')->__('Are you sure?')
        ));
        $this->getMassactionBlock()->addItem('status', array(
            'label'=> Mage::helper('dentalex_speakers')->__('Change status'),
            'url'  => $this->getUrl('*/*/massStatus', array('_current'=>true)),
            'additional' => array(
                'status' => array(
                        'name' => 'status',
                        'type' => 'select',
                        'class' => 'required-entry',
                        'label' => Mage::helper('dentalex_speakers')->__('Status'),
                        'values' => array(
                                '1' => Mage::helper('dentalex_speakers')->__('Enabled'),
                                '0' => Mage::helper('dentalex_speakers')->__('Disabled'),
                        )
                )
            )
        ));
        return $this;
    }
    /**
     * get the row url
     * @access public
     * @param Dentalex_Speakers_Model_Speaker
     * @return string
     * @author Ultimate Module Creator
     */
    public function getRowUrl($row){
        return $this->getUrl('*/*/edit', array('id' => $row->getId()));
    }
    /**
     * get the grid url
     * @access public
     * @return string
     * @author Ultimate Module Creator
     */
    public function getGridUrl(){
        return $this->getUrl('*/*/grid', array('_current'=>true));
    }
}
