<?php
/**
 * Dentalex_Speakers extension
 * 
 * NOTICE OF LICENSE
 * 
 * This source file is subject to the MIT License
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/mit-license.php
 * 
 * @category       Dentalex
 * @package        Dentalex_Speakers
 * @copyright      Copyright (c) 2014
 * @license        http://opensource.org/licenses/mit-license.php MIT License
 */
/**
 * fieldset element renderer
 * @category   Dentalex
 * @package    Dentalex_Speakers
 * @author      Ultimate Module Creator
 */
class Dentalex_Speakers_Block_Adminhtml_Speakers_Renderer_Fieldset_Element
    extends Mage_Adminhtml_Block_Widget_Form_Renderer_Fieldset_Element {
    /**
     * Initialize block template
     * @access protected
     * @author Ultimate Module Creator
     */
    protected function _construct() {
        $this->setTemplate('dentalex_speakers/form/renderer/fieldset/element.phtml');
    }

    /**
     * Retrieve data object related with form
     * @access public
     * @return mixed
     * @author Ultimate Module Creator
     */
    public function getDataObject() {
        return $this->getElement()->getForm()->getDataObject();
    }

    /**
     * Retrieve associated with element attribute object
     * @access public
     * @return Dentalex_Speakers_Model_Resource_Eav_Attribute
     * @author Ultimate Module Creator
     */
    public function getAttribute() {
        return $this->getElement()->getEntityAttribute();
    }

    /**
     * Retrieve associated attribute code
     * @access public
     * @return string
     * @author Ultimate Module Creator
     */
    public function getAttributeCode(){
        return $this->getAttribute()->getAttributeCode();
    }

    /**
     * Check "Use default" checkbox display availability
     * @access public
     * @return bool
     * @author Ultimate Module Creator
     */
    public function canDisplayUseDefault(){
        if ($attribute = $this->getAttribute()) {
            if (!$this->isScopeGlobal($attribute)
                && $this->getDataObject()
                && $this->getDataObject()->getId()
                && $this->getDataObject()->getStoreId()) {
                return true;
            }
        }
        return false;
    }

    /**
     * Check default value usage fact
     * @access public
     * @return bool
     * @author Ultimate Module Creator
     */
    public function usedDefault(){
        $defaultValue = $this->getDataObject()->getAttributeDefaultValue($this->getAttribute()->getAttributeCode());
        return !$defaultValue;
    }

    /**
     * Disable field in default value using case
     * @access public
     * @return Dentalex_Speakers_Block_Adminhtml_Speakers_Renderer_Fieldset_Element
     * @author Ultimate Module Creator
     */
    public function checkFieldDisable(){
        if ($this->canDisplayUseDefault() && $this->usedDefault()) {
            $this->getElement()->setDisabled(true);
        }
        return $this;
    }

    /**
     * Retrieve label of attribute scope
     * GLOBAL | WEBSITE | STORE
     * @access public
     * @return string
     * @author Ultimate Module Creator
     */
    public function getScopeLabel(){
        $html = '';
        $attribute = $this->getElement()->getEntityAttribute();
        if (!$attribute || Mage::app()->isSingleStoreMode()) {
            return $html;
        }
        if ($this->isScopeGlobal($attribute)) {
            $html.= Mage::helper('dentalex_speakers')->__('[GLOBAL]');
        }
        elseif ($this->isScopeWebsite($attribute)) {
            $html.= Mage::helper('dentalex_speakers')->__('[WEBSITE]');
        }
        elseif ($this->isScopeStore($attribute)) {
            $html.= Mage::helper('dentalex_speakers')->__('[STORE VIEW]');
        }
        return $html;
    }

    /**
     * Retrieve element label html
     * @access public
     * @return string
     * @author Ultimate Module Creator
     */
    public function getElementLabelHtml(){
        return $this->getElement()->getLabelHtml();
    }

    /**
     * Retrieve element html
     * @access public
     * @return string
     * @author Ultimate Module Creator
     */
    public function getElementHtml(){
        return $this->getElement()->getElementHtml();
    }
    /**
     * check if an attribute is global
     * @access public
     * @param Mage_Eav_Model_Entity_Attribute $attribute
     * @return bool
     * @author Ultimate Module Creator
     */
    public function isScopeGlobal($attribute){
        return $attribute->getIsGlobal() == 1;
    }
    /**
     * check if an attribute has website scope
     * @access public
     * @param Mage_Eav_Model_Entity_Attribute $attribute
     * @return bool
     * @author Ultimate Module Creator
     */
    public function isScopeWebsite($attribute){
        return $attribute->getIsGlobal() == 2;
    }
    /**
     * check if an attribute has store view scope
     * @access public
     * @param Mage_Eav_Model_Entity_Attribute $attribute
     * @return bool
     * @author Ultimate Module Creator
     */
    public function isScopeStore($attribute){
        return !$this->isScopeGlobal($attribute) && !$this->isScopeWebsite($attribute);
    }
}
