<?php
/**
 * Dentalex_Speakers extension
 * 
 * NOTICE OF LICENSE
 * 
 * This source file is subject to the MIT License
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/mit-license.php
 * 
 * @category       Dentalex
 * @package        Dentalex_Speakers
 * @copyright      Copyright (c) 2014
 * @license        http://opensource.org/licenses/mit-license.php MIT License
 */
/**
 * Speaker view block
 *
 * @category    Dentalex
 * @package     Dentalex_Speakers
 * @author      Ultimate Module Creator
 */
class Dentalex_Speakers_Block_Speaker_View
    extends Mage_Core_Block_Template {
    /**
     * initialize
     * @access public
     * @author Ultimate Module Creator
     */
    public function __construct(){
        parent::__construct();

        /** @var Dentalex_Speakers_Model_Resource_Speaker_Product_Collection $collection */
        $collection = $this->getCurrentSpeaker()->getSelectedProductsCollection();
        $collection->addAttributeToFilter('status',array('eq'=>1));

        $collection->getSelect()
            ->join(array('rev'=>'review'),'rev.entity_pk_value=e.entity_id','status_id')
            ->joinLeft(array('en'=>'catalog_product_entity_varchar'),'en.entity_id=e.entity_id','name')
            ->joinLeft(array('rev_d'=>'review_detail'),'rev.review_id = rev_d.review_id','rev_d.*')
            ->joinLeft(array('rat'=>'rating_option_vote'),'rev.review_id = rat.review_id AND rat.entity_pk_value=e.entity_id','*')
            ->reset(Zend_Db_Select::COLUMNS)
            ->columns('e.entity_id AS product_id')
            ->columns('en.value as product_name')
            ->columns('rev.review_id')
            ->columns('rev.created_at')
            ->columns('rat.remote_ip')
            ->columns('rat.customer_id')
            ->columns('rev_d.title')
            ->columns('rev_d.detail')
            ->columns('rev_d.nickname')
            ->columns('AVG(rat.percent ) AS vote')
            ->where('en.attribute_id = 65')
            ->where('rev.status_id = 1')
            ->where('rev_d.store_id = '.Mage::app()->getStore()->getStoreId())
            ->group('rev.review_id')
            ->order('rev.review_id DESC');

        $this->setReviews($collection);

    }

    /**
     * prepare the layout
     * @access protected
     * @return Dentalex_Speakers_Block_Speaker_List
     * @author Ultimate Module Creator
     */
    protected function _prepareLayout(){
        parent::_prepareLayout();
        /** @var Dentalex_Speakers_Block_Page_Html_Pager $pager */
        $pager = $this->getLayout()->createBlock('dentalex_speakers/page_html_pager', 'dentalex_speakers.speaker.html.pager')
            ->setCollection($this->getReviews());

        $this->setChild('pager', $pager);
        $this->getReviews()->load();
        return $this;
    }
    /**
     * get the pager html
     * @access public
     * @return string
     * @author Ultimate Module Creator
     */
    public function getPagerHtml(){
        return $this->getChildHtml('pager');
    }

    /**
     * get the current speaker
     * @access public
     * @return mixed (Dentalex_Speakers_Model_Speaker|null)
     * @author Ultimate Module Creator
     */
    public function getCurrentSpeaker(){
        return Mage::registry('current_speaker');
    }

    public function getSpeakerRating()
    {
        $collection = $this->getReviews();
        $rating = 0;
        $count = 0;
        foreach($collection->getItems() as $course){
            $count++;
            $rating += $course->getVote();
        }
        $obj = new stdClass();
        $obj->count = $count;
        $obj->rating = $count ? $rating/$count:0;
        return $obj;
    }
}
