<?php
/**
 * Dentalex_Speakers extension
 * 
 * NOTICE OF LICENSE
 * 
 * This source file is subject to the MIT License
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/mit-license.php
 * 
 * @category       Dentalex
 * @package        Dentalex_Speakers
 * @copyright      Copyright (c) 2014
 * @license        http://opensource.org/licenses/mit-license.php MIT License
 */
/**
 * Speakers default helper
 *
 * @category    Dentalex
 * @package     Dentalex_Speakers
 * @author      Ultimate Module Creator
 */
class Dentalex_Speakers_Helper_Data
    extends Mage_Core_Helper_Abstract {
    /**
     * convert array to options
     * @access public
     * @param $options
     * @return array
     * @author Ultimate Module Creator
     */
    public function convertOptions($options){
        $converted = array();
        foreach ($options as $option){
            if (isset($option['value']) && !is_array($option['value']) && isset($option['label']) && !is_array($option['label'])){
                $converted[$option['value']] = $option['label'];
            }
        }
        return $converted;
    }



    /**
     * Retrieve customer session model object
     *
     * @return Mage_Customer_Model_Session
     */
    protected function _getSession()
    {
        $name = (Mage::app()->getStore()->code == 'admin') ? 'adminhtml/session': 'customer/session';
        return Mage::getSingleton($name);
    }

    /**
     *
     * Retrieve saving avatar image URL
     */
    public function getUploadUrl()
    {
        return Mage::getUrl() . "avatar/ajax/savePhoto";
    }

    /**
     *
     * Save the avatar image after checks
     */
    public function processImage($file = 'image')
    {
        $session = $this->_getSession();
        $upload = new Zend_File_Transfer_Adapter_Http();

        try
        {
            $runValidation = $upload->isUploaded($file);
            if (!$runValidation) {
                return array();
            }

            $fileInfo = $upload->getFileInfo($file);
            $fileInfo = $fileInfo[$file];

        } catch (Exception $e)
        {
            // when file exceeds the upload_max_filesize, $_FILES is empty
            if (isset($_SERVER['CONTENT_LENGTH']) && $_SERVER['CONTENT_LENGTH'] > $this->_getUploadMaxFilesize()) {
                $error = $this->__("The file you uploaded is larger than %s Megabytes allowed by server",
                        $this->_bytesToMbytes($this->_getUploadMaxFilesize()));
                $session->addError($error);
                return false;
            } else {
                Mage::throwException(Mage::helper('avatar')->__("error uploading image"));
            }
        }

        /**
         * Option Validations
         */

        // Image dimensions
        $_dimentions = array();
        $_dimentions['maxwidth'] = '2000';
        $_dimentions['maxheight'] = '2000';
        if (count($_dimentions) > 0) {
            $upload->addValidator('ImageSize', false, $_dimentions);
        }

        // File extension
        $_allowed = $this->_parseExtensionsString("jpg/gif/png");
        if ($_allowed !== null) {
            $upload->addValidator('Extension', false, $_allowed);
        } else {
            $_forbidden = $this->_parseExtensionsString($this->getConfigData('forbidden_extensions'));
            if ($_forbidden !== null) {
                $upload->addValidator('ExcludeExtension', false, $_forbidden);
            }
        }

        // Maximum filesize
        $upload->addValidator('FilesSize', false, array('max' => $this->_getUploadMaxFilesize()));

        /**
         * Upload process
         */

        $this->_initFilesystem();
        if ($upload->isUploaded($file) && $upload->isValid($file)) {

            $extension = pathinfo(strtolower($fileInfo['name']), PATHINFO_EXTENSION);

            $fileHash = md5(file_get_contents($fileInfo['tmp_name']));
            $dispersion = Varien_File_Uploader::getDispretionPath($fileHash);

            $filePath = $dispersion;
            $filePath .= DS . $fileHash . '-' . time() . "." . $extension;

            $destination = $this->getPhotoTargetDir().$dispersion.'/';
//            var_dump($destination);exit;
            $this->_createWriteableDir($destination);
            $upload->setDestination($destination);

            $fileFullPath = $this->getPhotoTargetDir() . $filePath;
            $upload
                ->addFilter('Rename',
                    array('target' => $fileFullPath, 'overwrite' => true));
            if (!$upload->receive($file)) {
                Mage::throwException(Mage::helper('avatar')->__("File upload failed"));
            }
            $imageObj = new Varien_Image($fileFullPath);
            $imageObj->constrainOnly(TRUE);
            $imageObj->keepAspectRatio(TRUE);
            $imageObj->keepTransparency(TRUE);
            $imageObj->resize(600);
            $imageObj->save($fileFullPath);
            return ($filePath);

        } elseif ($upload->getErrors()) {
            foreach ($upload->getErrors() as $errorCode) {
                if ($errorCode == Zend_Validate_File_ExcludeExtension::FALSE_EXTENSION) {
                    $session->addError($this->__("The file '%s' has an invalid extension", $fileInfo['name']));
                    return false;
                } elseif ($errorCode == Zend_Validate_File_Extension::FALSE_EXTENSION) {
                    $session->addError($this->__("The file '%s' has an invalid extension", $fileInfo['name']));
                    return false;
                } elseif ($errorCode == Zend_Validate_File_ImageSize::WIDTH_TOO_BIG) {
                    $session->addError($this->__("Maximum allowed image width for '%s' is %s px.", $fileInfo['name'],
                            $_dimentions['maxwidth']));
                    return false;
                } elseif ($errorCode == Zend_Validate_File_ImageSize::HEIGHT_TOO_BIG) {
                    $session->addError($this->__("Maximum allowed image height for '%s' is %s px.", $fileInfo['name'],
                            $_dimentions['maxheight']));
                    return false;
                } elseif ($errorCode == Zend_Validate_File_FilesSize::TOO_BIG) {
                    $session->addError($this->__("The file you uploaded is larger than %s Megabytes allowed by server",
                            $fileInfo['name'], $this->_bytesToMbytes($this->_getUploadMaxFilesize())));
                    return false;
                }
            }
        } else {
            $session->addError($this->__('File upload failed'));
            return false;
        }
    }

    /**
     * Max upload filesize in bytes
     *
     * @return int
     */
    protected function _getUploadMaxFilesize()
    {
        return min($this->_getBytesIniValue('upload_max_filesize'), $this->_getBytesIniValue('post_max_size'));
    }

    /**
     * Return php.ini setting value in bytes
     *
     * @param string $ini_key php.ini Var name
     * @return int Setting value
     */
    protected function _getBytesIniValue($ini_key)
    {
        $_bytes = @ini_get($ini_key);

        // kilobytes
        if (stristr($_bytes, 'k')) {
            $_bytes = intval($_bytes) * 1024;
            // megabytes
        } elseif (stristr($_bytes, 'm')) {
            $_bytes = intval($_bytes) * 1024 * 1024;
            // gigabytes
        } elseif (stristr($_bytes, 'g')) {
            $_bytes = intval($_bytes) * 1024 * 1024 * 1024;
        }
        return (int) $_bytes;
    }

    /**
     * Main Destination directory
     *
     * @param boolean $relative If true - returns relative path to the webroot
     * @return string
     */
    public function getTargetDir($relative = false)
    {
        $fullPath = Mage::getBaseDir('media');
        return $relative ? str_replace(Mage::getBaseDir(), '', $fullPath) : $fullPath;
    }

    /**
     * Quote items destination directory
     *
     * @param boolean $relative If true - returns relative path to the webroot
     * @return string
     */
    public function getPhotoTargetDir($relative = false)
    {
        return $this->getTargetDir($relative) . DS . 'speaker';
    }

    /**
     * Directory structure initializing
     */
    protected function _initFilesystem()
    {
        $this->_createWriteableDir($this->getTargetDir());
        $this->_createWriteableDir($this->getPhotoTargetDir());

        // Directory listing and hotlink secure
        $io = new Varien_Io_File();
        $io->cd($this->getTargetDir());
        if (!$io->fileExists($this->getTargetDir() . DS . '.htaccess')) {
            $io->streamOpen($this->getTargetDir() . DS . '.htaccess');
            $io->streamLock(true);
            $io->streamWrite("Order deny,allow\nAllow from all\n");
            $io->streamWrite("Options -Indexes");
            $io->streamUnlock();
            $io->streamClose();
        }
    }

    /**
     * Create Writeable directory if it doesn't exist
     *
     * @param string Absolute directory path
     * @return void
     */
    protected function _createWriteableDir($path)
    {
        $io = new Varien_Io_File();
        if (!$io->isWriteable($path) && !$io->mkdir($path, 0777, true)) {
            Mage::throwException($this->__("Cannot create writeable directory '%s'", $path));
        }
    }

    /**
     * Parse file extensions string with various separators
     *
     * @param string $extensions String to parse
     * @return array|null
     */
    protected function _parseExtensionsString($extensions)
    {
        preg_match_all('/[a-z0-9]+/si', strtolower($extensions), $matches);
        if (isset($matches[0]) && is_array($matches[0]) && count($matches[0]) > 0) {
            return $matches[0];
        }
        return null;
    }

    /**
     * Simple check if file is image
     *
     * @param array $fileInfo File data from Zend_File_Transfer
     * @return boolean
     */
    protected function _isImage($fileInfo)
    {
        try
        {

            return strstr($fileInfo['type'], 'image/');

            // We can use Zend Validator, but the lack of mime types
            // $validator = new Zend_Validate_File_IsImage();
            // return $validator->isValid($fileInfo['tmp_name'], $fileInfo);

        } catch (Exception $e)
        {
            return false;
        }
    }
}
