<?php 
/**
 * Dentalex_Speakers extension
 * 
 * NOTICE OF LICENSE
 * 
 * This source file is subject to the MIT License
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/mit-license.php
 * 
 * @category       Dentalex
 * @package        Dentalex_Speakers
 * @copyright      Copyright (c) 2014
 * @license        http://opensource.org/licenses/mit-license.php MIT License
 */
/**
 * Speaker helper
 *
 * @category    Dentalex
 * @package     Dentalex_Speakers
 * @author      Ultimate Module Creator
 */
class Dentalex_Speakers_Helper_Speaker
    extends Mage_Core_Helper_Abstract {
    /**
     * get the url to the speakers list page
     * @access public
     * @return string
     * @author Ultimate Module Creator
     */
    public function getSpeakersUrl(){
        if ($listKey = Mage::getStoreConfig('dentalex_speakers/speaker/url_rewrite_list')) {
            return Mage::getUrl('', array('_direct'=>$listKey));
        }
        return Mage::getUrl('dentalex_speakers/speaker/index');
    }
    /**
     * check if breadcrumbs can be used
     * @access public
     * @return bool
     * @author Ultimate Module Creator
     */
    public function getUseBreadcrumbs(){
        return Mage::getStoreConfigFlag('dentalex_speakers/speaker/breadcrumbs');
    }
    /**
     * get base files dir
     * @access public
     * @return string
     * @author Ultimate Module Creator
     */
    public function getFileBaseDir(){
        return Mage::getBaseDir('media').DS.'speaker'.DS.'file';
    }
    /**
     * get base file url
     * @access public
     * @return string
     * @author Ultimate Module Creator
     */
    public function getFileBaseUrl(){
        return Mage::getBaseUrl('media').'speaker'.'/'.'file';
    }
    /**
	 * get speaker attribute source model
	 * @access public
	 * @param string $inputType
	 * @return mixed (string|null)
	 * @author Ultimate Module Creator
	 */
 	public function getAttributeSourceModelByInputType($inputType){
        $inputTypes = $this->getAttributeInputTypes();
        if (!empty($inputTypes[$inputType]['source_model'])) {
            return $inputTypes[$inputType]['source_model'];
        }
        return null;
    }
    /**
	 * get attribute input types
	 * @access public
	 * @param string $inputType
	 * @return array()
	 * @author Ultimate Module Creator
	 */
	public function getAttributeInputTypes($inputType = null){
        $inputTypes = array(
            'multiselect'   => array(
                'backend_model'     => 'eav/entity_attribute_backend_array'
            ),
            'boolean'       => array(
                'source_model'      => 'eav/entity_attribute_source_boolean'
            ),
            'file'			=> array(
            	'backend_model'		=> 'dentalex_speakers/speaker_attribute_backend_file'
            ),
            'image'			=> array(
            	'backend_model'		=> 'dentalex_speakers/speaker_attribute_backend_image'
            ),
        );

        if (is_null($inputType)) {
            return $inputTypes;
        } else if (isset($inputTypes[$inputType])) {
            return $inputTypes[$inputType];
        }
        return array();
    }
    /**
	 * get speaker attribute backend model
	 * @access public
	 * @param string $inputType
	 * @return mixed (string|null)
	 * @author Ultimate Module Creator
	 */
 	public function getAttributeBackendModelByInputType($inputType){
        $inputTypes = $this->getAttributeInputTypes();
        if (!empty($inputTypes[$inputType]['backend_model'])) {
            return $inputTypes[$inputType]['backend_model'];
        }
        return null;
    }
    /**
     * filter attribute content
     * @access public
     * @param Dentalex_Speakers_Model_Speaker $speaker
     * @param string $attributeHtml
     * @param string @attributeName
     * @return string
     * @author Ultimate Module Creator
     */
	public function speakerAttribute($speaker, $attributeHtml, $attributeName){
        $attribute = Mage::getSingleton('eav/config')->getAttribute(Dentalex_Speakers_Model_Speaker::ENTITY, $attributeName);
        if ($attribute && $attribute->getId() && !$attribute->getIsWysiwygEnabled()) {
			if ($attribute->getFrontendInput() == 'textarea') {
            	$attributeHtml = nl2br($attributeHtml);
            }
        }
        if ($attribute->getIsWysiwygEnabled()) {
            $attributeHtml = $this->_getTemplateProcessor()->filter($attributeHtml);
        }
        return $attributeHtml;
    }
    /**
     * get the template processor
     * @access protected
     * @return Mage_Catalog_Model_Template_Filter
     * @author Ultimate Module Creator
     */
	protected function _getTemplateProcessor(){
        if (null === $this->_templateProcessor) {
            $this->_templateProcessor = Mage::helper('catalog')->getPageTemplateProcessor();
        }
        return $this->_templateProcessor;
    }
}
