<?php
/**
 * Dentalex_Speakers extension
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the MIT License
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/mit-license.php
 *
 * @category       Dentalex
 * @package        Dentalex_Speakers
 * @copyright      Copyright (c) 2014
 * @license        http://opensource.org/licenses/mit-license.php MIT License
 */

/**
 * Adminhtml observer
 *
 * @category    Dentalex
 * @package     Dentalex_Speakers
 * @author      Ultimate Module Creator
 */
class Dentalex_Speakers_Model_Adminhtml_Observer
{
    /**
     * check if tab can be added
     * @access protected
     * @param Mage_Catalog_Model_Product $product
     * @return bool
     * @author Ultimate Module Creator
     */
    protected function _canAddTab($product)
    {
//        if ($product->getId()){
//            return true;
//        }
        if (!$product->getAttributeSetId()) {
            return false;
        }
        $request = Mage::app()->getRequest();
        if ($request->getParam('type') != 'configurable') {
//            if ($request->getParam('attributes')){
            return true;
//            }
        }
        return false;
    }

    /**
     * add the speaker tab to products
     * @access public
     * @param Varien_Event_Observer $observer
     * @return Dentalex_Speakers_Model_Adminhtml_Observer
     * @author Ultimate Module Creator
     */
    public function addProductSpeakerBlock($observer)
    {
        $block = $observer->getEvent()->getBlock();
        $product = Mage::registry('product');
        if ($block instanceof Mage_Adminhtml_Block_Catalog_Product_Edit_Tabs && $this->_canAddTab($product)) {
            $block->addTab('speakers', array(
                'label' => Mage::helper('dentalex_speakers')->__('Speakers'),
                'url' => Mage::helper('adminhtml')->getUrl('adminhtml/speakers_speaker_catalog_product/speakers', array('_current' => true)),
                'class' => 'ajax',
            ));
        }
        return $this;
    }

    /**
     * save speaker - product relation
     * @access public
     * @param Varien_Event_Observer $observer
     * @return Dentalex_Speakers_Model_Adminhtml_Observer
     * @author Ultimate Module Creator
     */
    public function saveProductSpeakerData($observer)
    {
        $post = Mage::app()->getRequest()->getPost('speakers', -1);
        if ($post != '-1') {
            $post = Mage::helper('adminhtml/js')->decodeGridSerializedInput($post);
            $product = Mage::registry('product');
            $speakerProduct = Mage::getResourceSingleton('dentalex_speakers/speaker_product')->saveProductRelation($product, $post);
        }
        return $this;
    }


    /**
     * Save speakers attribute for search
     *
     * @@author Taras Trishchuk
     * @return Dentalex_Speakers_Model_Resource_Speaker_Product
     */
    public function saveSpeakersAttribute($observer)
    {
        /**
         * @var $speaker Mage_Catalog_Model_Product
         */
        $product = $observer->getEvent()->getProduct();

        $collection = Mage::getResourceModel('dentalex_speakers/speaker_collection');

        $collection->addProductFilter($product)
            ->addAttributeToSelect(array('firstname', 'middle_name', 'lastname', 'job', 'medical_degree', 'designations' ));

        $index = '';
        foreach($collection as $speaker){
            $index .=  $speaker->getMedicalDegree(). ' ' .
                $speaker->getDesignations(). ' '.
                 $speaker->getFirstname(). ' ' .
                 $speaker->getLastname(). ' ' .
                 $speaker->getJob() . ', ';
        }

        $product->setSpeakers($index);
        return $this;
    }


}
