<?php
/**
 * Dentalex_Speakers extension
 * 
 * NOTICE OF LICENSE
 * 
 * This source file is subject to the MIT License
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/mit-license.php
 * 
 * @category       Dentalex
 * @package        Dentalex_Speakers
 * @copyright      Copyright (c) 2014
 * @license        http://opensource.org/licenses/mit-license.php MIT License
 */
/**
 * Speaker - product relation model
 *
 * @category    Dentalex
 * @package     Dentalex_Speakers
 * @author      Ultimate Module Creator
 */
class Dentalex_Speakers_Model_Resource_Speaker_Product
    extends Mage_Core_Model_Resource_Db_Abstract {
    /**
     * initialize resource model
     * @access protected
     * @see Mage_Core_Model_Resource_Abstract::_construct()
     * @author Ultimate Module Creator
     */
    protected function  _construct(){
        $this->_init('dentalex_speakers/speaker_product', 'rel_id');
    }
    /**
     * Save speaker - product relations
     * @access public
     * @param Dentalex_Speakers_Model_Speaker $speaker
     * @param array $data
     * @return Dentalex_Speakers_Model_Resource_Speaker_Product
     * @author Ultimate Module Creator
     */
    public function saveSpeakerRelation(Dentalex_Speakers_Model_Speaker $speaker, $data){
        if (!is_array($data)) {
            $data = array();
        }

        /** @var Dentalex_Speakers_Model_Resource_Speaker_Product_Collection $productCollection */
        $productCollection = $speaker->getSelectedProductsCollection();
        $productIds = $productCollection->getAllIds();
        $addedCourses = array_diff(array_keys($data),$productIds);

        $deleteCondition = $this->_getWriteAdapter()->quoteInto('speaker_id=?', $speaker->getId());
        $this->_getWriteAdapter()->delete($this->getMainTable(), $deleteCondition);

        if(!empty($addedCourses)){

            /** @var Dentalex_Users_Model_Customer_Customer $customer */
            $customer = Mage::getModel('customer/customer')
                ->load($speaker->getCustomerId());

            $collection = Mage::getModel('catalog/product')->getCollection();
            $collection->addIdFilter($addedCourses)
                ->addAttributeToSelect('*');
            foreach($collection->getItems() as $course){
                $course->time = Mage::getModel('core/date')->date('h:i A', strtotime($course->getStartCourse()));
                $course->date = Mage::helper('core')->formatDate( $course->getStartCourse(), 'medium');
                $course->place = ($course->hasGeoName() ? $course->getGeoName().' ':'').
                    ($course->hasGeoName() ? $course->getGeoName().' ':'').
                    ($course->hasGeoStreet() ? $course->getGeoStreet().' ':'').
                    ($course->hasGeoCity() ? $course->getGeoCity().' ':'').
                    ($course->hasGeoRegion() ? $course->getGeoRegion():'');

                $customer->sendNewCourseAdd($course);
            }
        }
        foreach ($data as $productId => $info) {
            $this->_getWriteAdapter()->insert($this->getMainTable(), array(
                'speaker_id'      => $speaker->getId(),
                'product_id'     => $productId,
                'position'      => @$info['position']
            ));
        }
        return $this;
    }


    /**
     * Save  product - speaker relations
     *
     * @access public
     * @param Mage_Catalog_Model_Product $product
     * @param array $data
     * @return Dentalex_Speakers_Model_Resource_Speaker_Product
     * @@author Ultimate Module Creator
     */
    public function saveProductRelation($product, $data){
        if (!is_array($data)) {
            $data = array();
        }
        /** @var Dentalex_Speakers_Model_Resource_Speaker_Collection $collection */
        $collection = Mage::getResourceModel('dentalex_speakers/speaker_collection');
        $collection->addProductFilter($product)
            ->addAttributeToSelect('customer_id');

        $speakerIds = $collection->getAllIds();
        $addedSpeakers = array_diff(array_keys($data),$speakerIds);

        if(!empty($addedSpeakers)){
            foreach($addedSpeakers as $speakerId){
                $speaker = Mage::getModel('dentalex_speakers/speaker')->load($speakerId);

                /** @var Dentalex_Users_Model_Customer_Customer $customer */
                $customer = Mage::getModel('customer/customer')
                    ->load($speaker->getCustomerId());

                $product->time = Mage::getModel('core/date')->date('h:i A', strtotime($product->getStartCourse()));
                $product->date = Mage::helper('core')->formatDate( $product->getStartCourse(), 'medium');

                $product->place = ($product->hasGeoName() ? $product->getGeoName().' ':'').
                    ($product->hasGeoStreet() ? $product->getGeoStreet().' ':'').
                    ($product->hasGeoCity() ? $product->getGeoCity().' ':'').
                    ($product->hasGeoRegion() ? $product->getGeoRegion().' ':'').
                    ($product->hasGeoCountry() ? $product->getGeoCountry():'');

                $customer->sendNewCourseAdd($product);

            }
        }

        $deleteCondition = $this->_getWriteAdapter()->quoteInto('product_id=?', $product->getId());
        $this->_getWriteAdapter()->delete($this->getMainTable(), $deleteCondition);

        foreach ($data as $speakerId => $info) {
            $this->_getWriteAdapter()->insert($this->getMainTable(), array(
                'speaker_id' => $speakerId,
                'product_id' => $product->getId(),
                'position'   => @$info['position']
            ));
        }
        return $this;
    }

    public function refuseSpeakerProduct($speakerId, $productId)
    {

        return $this->_getWriteAdapter()
            ->delete($this->getMainTable(),array('product_id=?'=>$productId,'speaker_id=?'=>$speakerId));
    }
}
