<?php
/**
 * Dentalex_Speakers extension
 * 
 * NOTICE OF LICENSE
 * 
 * This source file is subject to the MIT License
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/mit-license.php
 * 
 * @category       Dentalex
 * @package        Dentalex_Speakers
 * @copyright      Copyright (c) 2014
 * @license        http://opensource.org/licenses/mit-license.php MIT License
 */
/**
 * Speaker admin controller
 *
 * @category    Dentalex
 * @package     Dentalex_Speakers
 * @author      Ultimate Module Creator
 */
class Dentalex_Speakers_Adminhtml_Speakers_SpeakerController
    extends Mage_Adminhtml_Controller_Action {
    /**
     * constructor - set the used module name
     * @access protected
     * @return void
     * @see Mage_Core_Controller_Varien_Action::_construct()
     * @author Ultimate Module Creator
     */
    protected function _construct(){
        $this->setUsedModuleName('Dentalex_Speakers');
    }
    /**
     * init the speaker
     * @access protected 
     * @return Dentalex_Speakers_Model_Speaker
     * @author Ultimate Module Creator
     */
    protected function _initSpeaker(){
        $this->_title($this->__('Speakers'))
             ->_title($this->__('Manage Speakers'));

        $speakerId  = (int) $this->getRequest()->getParam('id');
        $speaker    = Mage::getModel('dentalex_speakers/speaker')
            ->setStoreId($this->getRequest()->getParam('store', 0));

        if ($speakerId) {
            $speaker->load($speakerId);

            $userId = Mage::getSingleton('admin/session')->getUser()->getId();

            $role = strtolower(Mage::getModel('admin/user')->load($userId)->getRole()->getData('role_name'));

            if($speaker->getId() && $role !== 'administrators' && $speaker->getData('created_by') != $userId){
                Mage::getSingleton('core/session')->addError("You don't have permissions");
                session_write_close();
                $this->_redirect('/speakers_speaker/index');
            }
        }
        Mage::register('current_speaker', $speaker);
        return $speaker;
    }
    /**
     * default action for speaker controller
     * @access public
     * @return void
     * @author Ultimate Module Creator
     */
    public function indexAction(){
        $this->_title($this->__('Speakers'))
             ->_title($this->__('Manage Speakers'));
        $this->loadLayout();
        $this->renderLayout();
    }
    /**
     * new speaker action
     * @access public
     * @return void
     * @author Ultimate Module Creator
     */
    public function newAction(){
        $this->_forward('edit');
    }
    /**
     * edit speaker action
     * @access public
     * @return void
     * @author Ultimate Module Creator
     */
    public function editAction(){
        $speakerId  = (int) $this->getRequest()->getParam('id');

        $speaker = $this->_initSpeaker();
        if ($speakerId && !$speaker->getId()) {
            $this->_getSession()->addError(Mage::helper('dentalex_speakers')->__('This speaker no longer exists.'));
            $this->_redirect('*/*/');
            return;
        }
        if ($data = Mage::getSingleton('adminhtml/session')->getSpeakerData(true)){
            $speaker->setData($data);
        }
        $this->_title($speaker->getFullname());
        Mage::dispatchEvent('dentalex_speakers_speaker_edit_action', array('speaker' => $speaker));
        $this->loadLayout();
        if ($speaker->getId()){
            if (!Mage::app()->isSingleStoreMode() && ($switchBlock = $this->getLayout()->getBlock('store_switcher'))) {
                $switchBlock->setDefaultStoreName(Mage::helper('dentalex_speakers')->__('Default Values'))
                    ->setWebsiteIds($speaker->getWebsiteIds())
                    ->setSwitchUrl($this->getUrl('*/*/*', array('_current'=>true, 'active_tab'=>null, 'tab' => null, 'store'=>null)));
            }
        }
        else{
            $this->getLayout()->getBlock('left')->unsetChild('store_switcher');
        }
        $this->getLayout()->getBlock('head')->setCanLoadExtJs(true);
        $this->renderLayout();
    }
    /**
     * save speaker action
     * @access public
     * @return void
     * @author Ultimate Module Creator
     */
    public function saveAction(){
        $storeId        = $this->getRequest()->getParam('store');
        $redirectBack   = $this->getRequest()->getParam('back', false);
        $speakerId      = $this->getRequest()->getParam('id');
        $isEdit         = (int)($this->getRequest()->getParam('id') != null);
        $data = $this->getRequest()->getPost();
        if ($data) {
            $speaker    = $this->_initSpeaker();
            $speakerData = $this->getRequest()->getPost('speaker', array());

            $speaker->addData($speakerData);

            $customerId = $speaker->customer_id;
            $customer = Mage::getModel('customer/customer');
            $customerForm = Mage::getModel('customer/form');
            $customerForm->setEntity($customer)
                ->setFormCode('adminhtml_customer')
                ->ignoreInvisible(false)
            ;

            if($speaker->getId() && !empty($customerId)){
                $customer->load($customerId);
            } else {
                $speaker->setData('created_by',Mage::getSingleton('admin/session')->getUser()->getId());
            }

            if(empty($customer->website_id))
                $customer->setData('website_id',1);

            if(empty($customer->is_lector))
                $customer->setData('is_lector',1);

            $isNewCustomer = $customer->isObjectNew();

            if ($isNewCustomer) {
                $customer->setPassword($data['speaker']['password']);
                $customer->setForceConfirmed(true);
                if ($customer->getPassword() == 'auto') {
                    $customer->setPassword($customer->generatePassword());
                }
            }

            $customerForm->compactData($speakerData);
            $customer->setForceConfirmed(true);

            $speaker->fullname = $speakerData['firstname'] . ' ' . $speakerData['lastname'];
            $speaker->setAttributeSetId($speaker->getDefaultAttributeSetId());
                $products = $this->getRequest()->getPost('products', -1);
                if ($products != -1) {
                    $speaker->setProductsData(Mage::helper('adminhtml/js')->decodeGridSerializedInput($products));
                }
            if ($useDefaults = $this->getRequest()->getPost('use_default')) {
                foreach ($useDefaults as $attributeCode) {
                    $speaker->setData($attributeCode, false);
                }
            }
            $connection = Mage::getSingleton('core/resource')->getConnection('core_write');
            try {

                $connection->beginTransaction();
                $customer->save();
                $speaker->setData('customer_id',$customer->getId());
                $speaker->save();
                $speakerId = $speaker->getId();
                $customer->setData('speaker_id',$speakerId)->save();

                if ($customer->getWebsiteId() &&  $isNewCustomer) {
                    if ($isNewCustomer) {
                        $customer->sendNewAccountEmail('speaker', '', $storeId);
                    }
                }

                if (!empty($speakerData['new_password'])) {
                    $newPassword = $speakerData['new_password'];
                    if ($newPassword == 'auto') {
                        $newPassword = $customer->generatePassword();
                    }
                    $customer->changePassword($newPassword);
                    $customer->sendPasswordReminderEmail();
                }

                if(isset($_FILES['image']['name']) && !empty($_FILES['image']['name'])){
                    if(!$img = Mage::helper('dentalex_speakers')->processImage()){
                        throw new Exception();
                    }
                    if(file_exists(Mage::helper('dentalex_speakers/speaker_image')->getImageBaseDir().$speaker->image))
                        unlink(Mage::helper('dentalex_speakers/speaker_image')->getImageBaseDir().$speaker->image);
                    $speaker->setData('image', $img);
                    $speaker->save();
                }

                $this->_getSession()->addSuccess(Mage::helper('dentalex_speakers')->__('Speaker was saved'));
                $connection->commit();
            }
            catch (Mage_Core_Exception $e) {
                Mage::logException($e);
                $this->_getSession()->addError($e->getMessage())
                    ->setSpeakerData($speakerData);
                $redirectBack = true;
                $connection->rollback();
            }
            catch (Exception $e){
                Mage::logException($e);
                $this->_getSession()->addError(Mage::helper('dentalex_speakers')->__('Error saving speaker'))
                    ->setSpeakerData($speakerData);
                $redirectBack = true;
                $connection->rollback();
            }
        }

        if ($this->getRequest()->getParam('popup')) {
            $this->_redirect('*/*/created', array(
                'id'       => $this->getRequest()->getParam('product'),
                '_current' => true
            ));
        } elseif ($redirectBack) {
            $this->_redirect('*/*/edit', array(
                'id'    => $speakerId,
                '_current'=>true
            ));
        } else {
            $this->_redirect('*/*/', array('store'=>$storeId));
        }
    }


    public function createdAction()
    {
        $this->_getSession()->addNotice(
            Mage::helper('catalog')->__('Please click on the Close Window button if it is not closed automatically.')
        );
        $this->loadLayout('popup');
        $this->_addContent(
            $this->getLayout()->createBlock('dentalex_speakers/adminhtml_speaker_created')
        );
        $this->renderLayout();
    }
    /**
     * delete speaker
     * @access public
     * @return void
     * @author Ultimate Module Creator
     */
    public function deleteAction(){
        if ($id = $this->getRequest()->getParam('id')) {
            $speaker = Mage::getModel('dentalex_speakers/speaker')->load($id);

            $userId = Mage::getSingleton('admin/session')->getUser()->getId();

            $role = strtolower(Mage::getModel('admin/user')->load($userId)->getRole()->getData('role_name'));

            try {
                if($speaker->created_by &&  $role !== 'administrators' && $speaker->created_by != $userId)
                    throw new Exception("You don't have permissions");
                Mage::getModel('customer/customer')->load($speaker->customer_id)->delete();

                $speaker->delete();
                $this->_getSession()->addSuccess(Mage::helper('dentalex_speakers')->__('The speakers has been deleted.'));
            }
            catch (Exception $e) {
                $this->_getSession()->addError($e->getMessage());
            }
        }
        $this->getResponse()->setRedirect($this->getUrl('*/*/', array('store'=>$this->getRequest()->getParam('store'))));
    }
    /**
     * mass delete speakers
     * @access public
     * @return void
     * @author Ultimate Module Creator
     */
    public function massDeleteAction() {
        $speakerIds = $this->getRequest()->getParam('speaker');
        if (!is_array($speakerIds)) {
            $this->_getSession()->addError($this->__('Please select speakers.'));
        }
        else {
            $userId = Mage::getSingleton('admin/session')->getUser()->getId();

            $role = strtolower(Mage::getModel('admin/user')->load($userId)->getRole()->getData('role_name'));

            try {
                foreach ($speakerIds as $speakerId) {
                    $speaker = Mage::getSingleton('dentalex_speakers/speaker')->load($speakerId);
                    if($speaker->created_by &&  $role !== 'administrators' && $speaker->created_by != $userId)
                        continue;
                    Mage::getModel('customer/customer')->load($speaker->customer_id)->delete();
                    Mage::dispatchEvent('dentalex_speakers_controller_speaker_delete', array('speaker' => $speaker));
                    $speaker->delete();
                }
                $this->_getSession()->addSuccess(
                    Mage::helper('dentalex_speakers')->__('Total of %d record(s) have been deleted.', count($speakerIds))
                );
            } catch (Exception $e) {
                $this->_getSession()->addError($e->getMessage());
            }
        }
        $this->_redirect('*/*/index');
    }
    /**
     * mass status change - action
     * @access public
     * @return void
     * @author Ultimate Module Creator
     */
    public function massStatusAction(){
        $speakerIds = $this->getRequest()->getParam('speaker');
        if(!is_array($speakerIds)) {
            Mage::getSingleton('adminhtml/session')->addError(Mage::helper('dentalex_speakers')->__('Please select speakers.'));
        }
        else {
            try {
                foreach ($speakerIds as $speakerId) {
                $speaker = Mage::getSingleton('dentalex_speakers/speaker')->load($speakerId)
                            ->setStatus($this->getRequest()->getParam('status'))
                            ->setIsMassupdate(true)
                            ->save();
                }
                $this->_getSession()->addSuccess($this->__('Total of %d speakers were successfully updated.', count($speakerIds)));
            }
            catch (Mage_Core_Exception $e){
                Mage::getSingleton('adminhtml/session')->addError($e->getMessage());
            }
            catch (Exception $e) {
                Mage::getSingleton('adminhtml/session')->addError(Mage::helper('dentalex_speakers')->__('There was an error updating speakers.'));
                Mage::logException($e);
            }
        }
        $this->_redirect('*/*/index');
    }
    /**
     * grid action
     * @access public
     * @return void
     * @author Ultimate Module Creator
     */
    public function gridAction(){
        $this->loadLayout();
        $this->renderLayout();
    }
    /**
     * restrict access
     * @access protected
     * @return bool
     * @see Mage_Adminhtml_Controller_Action::_isAllowed()
     * @author Ultimate Module Creator
     */
     protected function _isAllowed(){
        return Mage::getSingleton('admin/session')->isAllowed('dentalex_speakers/speaker');
    }
    /**
     * Export speakers in CSV format
     * @access public
     * @return void
     * @author Ultimate Module Creator
     */
    public function exportCsvAction(){
        $fileName   = 'speakers.csv';
        $content    = $this->getLayout()->createBlock('dentalex_speakers/adminhtml_speaker_grid')
            ->getCsvFile();
        $this->_prepareDownloadResponse($fileName, $content);
    }

    /**
     * Export speakers in Excel format
     * @access public
     * @return void
     * @author Ultimate Module Creator
     */
    public function exportExcelAction(){
        $fileName   = 'speaker.xls';
        $content    = $this->getLayout()->createBlock('dentalex_speakers/adminhtml_speaker_grid')
            ->getExcelFile();
        $this->_prepareDownloadResponse($fileName, $content);
    }
    /**
     * Export speakers in XML format
     * @access public
     * @return void
     * @author Ultimate Module Creator
     */
    public function exportXmlAction(){
        $fileName   = 'speaker.xml';
        $content    = $this->getLayout()->createBlock('dentalex_speakers/adminhtml_speaker_grid')
            ->getXml();
        $this->_prepareDownloadResponse($fileName, $content);
    }
    /**
     * wysiwyg editor action
     * @access public
     * @return void
     * @author Ultimate Module Creator
     */
    public function wysiwygAction() {
        $elementId = $this->getRequest()->getParam('element_id', md5(microtime()));
        $storeId = $this->getRequest()->getParam('store_id', 0);
        $storeMediaUrl = Mage::app()->getStore($storeId)->getBaseUrl(Mage_Core_Model_Store::URL_TYPE_MEDIA);

        $content = $this->getLayout()->createBlock('dentalex_speakers/adminhtml_speakers_helper_form_wysiwyg_content', '', array(
            'editor_element_id' => $elementId,
            'store_id'          => $storeId,
            'store_media_url'   => $storeMediaUrl,
        ));
        $this->getResponse()->setBody($content->toHtml());
    }
    /**
     * get grid of products action
     * @access public
     * @return void
     * @author Ultimate Module Creator
     */
    public function productsAction(){
        $this->_initSpeaker();
        $this->loadLayout();
        $this->getLayout()->getBlock('speaker.edit.tab.product')
            ->setSpeakerProducts($this->getRequest()->getPost('speaker_products', null));
        $this->renderLayout();
    }
    /**
     * get grid of products action
     * @access public
     * @return void
     * @author Ultimate Module Creator
     */
    public function productsgridAction(){
        $this->_initSpeaker();
        $this->loadLayout();
        $this->getLayout()->getBlock('speaker.edit.tab.product')
            ->setSpeakerProducts($this->getRequest()->getPost('speaker_products', null));
        $this->renderLayout();
    }
}
