<?php
/**
 * Dentalex_Speakers extension
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the MIT License
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/mit-license.php
 *
 * @category       Dentalex
 * @package        Dentalex_Speakers
 * @copyright      Copyright (c) 2014
 * @license        http://opensource.org/licenses/mit-license.php MIT License
 */

/**
 * Speaker front contrller
 *
 * @category    Dentalex
 * @package     Dentalex_Speakers
 * @author      Ultimate Module Creator
 */
class Dentalex_Speakers_SpeakerController
    extends Mage_Core_Controller_Front_Action
{
    /**
     * default action
     * @access public
     * @return void
     * @author Ultimate Module Creator
     */
    public function indexAction()
    {
        $this->loadLayout();
        $this->_initLayoutMessages('catalog/session');
        $this->_initLayoutMessages('customer/session');
        $this->_initLayoutMessages('checkout/session');
        if (Mage::helper('dentalex_speakers/speaker')->getUseBreadcrumbs()) {
            if ($breadcrumbBlock = $this->getLayout()->getBlock('breadcrumbs')) {
                $breadcrumbBlock->addCrumb('home', array(
                        'label' => Mage::helper('dentalex_speakers')->__('Home'),
                        'link' => Mage::getUrl(),
                    )
                );
                $breadcrumbBlock->addCrumb('speakers', array(
                        'label' => Mage::helper('dentalex_speakers')->__('Speakers'),
                        'link' => '',
                    )
                );
            }
        }
        $this->renderLayout();
    }

    /**
     * init Speaker
     * @access protected
     * @return Dentalex_Speakers_Model_Entity
     * @author Ultimate Module Creator
     */
    protected function _initSpeaker()
    {
        $speakerId = $this->getRequest()->getParam('id', 0);
        $speaker = Mage::getModel('dentalex_speakers/speaker')
            ->setStoreId(Mage::app()->getStore()->getId())
            ->load($speakerId);
        if (!$speaker->getId()) {
            return false;
        } elseif (!$speaker->getStatus()) {
            $this->_redirect('no-route');
        }
        return $speaker;
    }

    /**
     * view speaker action
     * @access public
     * @return void
     * @author Ultimate Module Creator
     */
    public function viewAction()
    {
        $speaker = $this->_initSpeaker();
        if (!$speaker) {
            $this->_forward('no-route');
            return;
        }
        Mage::register('current_speaker', $speaker);
        $this->loadLayout();
        $this->_initLayoutMessages('catalog/session');
        $this->_initLayoutMessages('customer/session');
        $this->_initLayoutMessages('checkout/session');
        if ($root = $this->getLayout()->getBlock('root')) {
            $root->addBodyClass('speakers-speaker speakers-speaker' . $speaker->getId());
        }
        if (Mage::helper('dentalex_speakers/speaker')->getUseBreadcrumbs()) {
            if ($breadcrumbBlock = $this->getLayout()->getBlock('breadcrumbs')) {
                $breadcrumbBlock->addCrumb('home', array(
                        'label' => Mage::helper('dentalex_speakers')->__('Home'),
                        'link' => Mage::getUrl(),
                    )
                );
//                $breadcrumbBlock->addCrumb('speakers', array(
//                        'label' => Mage::helper('dentalex_speakers')->__('Speakers'),
//                        'link' => Mage::helper('dentalex_speakers/speaker')->getSpeakersUrl(),
//                    )
//                );
                $breadcrumbBlock->addCrumb('speaker', array(
                        'label' => $speaker->getFullname(),
                        'link' => '',
                    )
                );
            }
        }
        $this->getLayout()->getBlock('head')->setTitle($speaker->getFullname());
        $this->renderLayout();
    }
}
