<?php
require_once "Mage/Customer/controllers/AccountController.php";  
class Dentalex_Users_Customer_AccountController extends Mage_Customer_AccountController{

    public function editAction()
    {
        $this->loadLayout();
        $this->_initLayoutMessages('customer/session');
        $this->_initLayoutMessages('catalog/session');

        $block = $this->getLayout()->getBlock('customer_edit');
        if ($block) {
            $block->setRefererUrl($this->_getRefererUrl());
        }
        $data = $this->_getSession()->getCustomerFormData(true);
        $customer = $this->_getSession()->getCustomer();
        if (!empty($data)) {
            $customer->addData($data);
        }
        if($customer->is_lector){
            $speaker = Mage::getModel('dentalex_speakers/speaker')->getResourceCollection()
                ->addAttributeToFilter('customer_id', array('eq' => $customer->getId()))
                ->addAttributeToSelect('*')
                ->getFirstItem();
            Mage::register('current_speaker', $speaker);
        }
        if ($this->getRequest()->getParam('changepass') == 1) {
            $customer->setChangePassword(1);
        }

        $this->getLayout()->getBlock('head')->setTitle($this->__('Account Information'));
        $this->getLayout()->getBlock('messages')->setEscapeMessageFlag(true);
        $this->renderLayout();
    }

    /**
     * Change customer password action
     */
    public function editPostAction()
    {
        if (!$this->_validateFormKey()) {
            return $this->_redirect('*/*/edit');
        }

        if ($this->getRequest()->isPost()) {
            /** @var $customer Mage_Customer_Model_Customer */
            $customer = $this->_getSession()->getCustomer();

            /** @var $customerForm Mage_Customer_Model_Form */
            $customerForm = $this->_getModel('customer/form');
            $customerForm->setFormCode('customer_account_edit')
                ->setEntity($customer);

            $customerData = $customerForm->extractData($this->getRequest());

            $errors = array();
            $customerErrors = $customerForm->validateData($customerData);
            if ($customerErrors !== true) {
                $errors = array_merge($customerErrors, $errors);
            } else {
                $customerForm->compactData($customerData);
                $errors = array();

                // If password change was requested then add it to common validation scheme
                if ($this->getRequest()->getParam('change_password')) {
                    $currPass   = $this->getRequest()->getPost('current_password');
                    $newPass    = $this->getRequest()->getPost('password');
                    $confPass   = $this->getRequest()->getPost('confirmation');

                    $oldPass = $this->_getSession()->getCustomer()->getPasswordHash();
                    if ( $this->_getHelper('core/string')->strpos($oldPass, ':')) {
                        list($_salt, $salt) = explode(':', $oldPass);
                    } else {
                        $salt = false;
                    }

                    if ($customer->hashPassword($currPass, $salt) == $oldPass) {
                        if (strlen($newPass)) {
                            /**
                             * Set entered password and its confirmation - they
                             * will be validated later to match each other and be of right length
                             */
                            $customer->setPassword($newPass);
                            $customer->setConfirmation($confPass);
                        } else {
                            $errors[] = $this->__('New password field cannot be empty.');
                        }
                    } else {
                        $errors[] = $this->__('Invalid current password');
                    }
                }

                // Validate account and compose list of errors if any
                $customerErrors = $customer->validate();
                if (is_array($customerErrors)) {
                    $errors = array_merge($errors, $customerErrors);
                }
            }
            if($customer->is_lector){
                $speaker = Mage::getModel('dentalex_speakers/speaker')->getResourceCollection()
                    ->addAttributeToFilter('customer_id', array('eq' => $customer->getId()))
                    ->addAttributeToSelect('*')
                    ->getFirstItem();

                $speaker->setData('firstname', $customer->firstname);
                $speaker->setData('lastname',$customer->lastname);
                $speaker->setData('email',$customer->email);
                $speaker->setData('fullname',$speaker->firstname . ' ' . $speaker->lastname);

                $speaker->setData('medical_degree',$this->getRequest()->getPost('medical_degree'));
                $speaker->setData('biography',$this->getRequest()->getPost('biography'));
                $speaker->setData('middle_name',$this->getRequest()->getPost('middle_name'));
                $speaker->setData('designations',$this->getRequest()->getPost('designations'));

                if(isset($_FILES['image']['name']) && !empty($_FILES['image']['name'])){
                    if(!$img = Mage::helper('dentalex_speakers')->processImage()){
                        $errors[] = Mage::getSingleton('customer/session')->getMessages(true)->getLastAddedMessage()->getCode();
                    } else {
                        if(file_exists(Mage::helper('dentalex_speakers/speaker_image')->getImageBaseDir().$speaker->image))
                            unlink(Mage::helper('dentalex_speakers/speaker_image')->getImageBaseDir().$speaker->image);
                        $speaker->setData('image', $img);
                        $speaker->save();
                    }
                }else{
                    $speaker->save();
                }
            }
            if (!empty($errors)) {
                $this->_getSession()->setCustomerFormData($this->getRequest()->getPost());
                foreach ($errors as $message) {
                    $this->_getSession()->addError($message);
                }
                $this->_redirect('*/*/edit');
                return $this;
            }


            try {
                $customer->setConfirmation(null);
                $customer->save();
                $this->_getSession()->setCustomer($customer)
                    ->addSuccess($this->__('The account information has been saved.'));

                $this->_redirect('customer/account');
                return;
            } catch (Mage_Core_Exception $e) {
                $this->_getSession()->setCustomerFormData($this->getRequest()->getPost())
                    ->addError($e->getMessage());
            } catch (Exception $e) {
                $this->_getSession()->setCustomerFormData($this->getRequest()->getPost())
                    ->addException($e, $this->__('Cannot save the customer.'));
            }
        }

        $this->_redirect('*/*/edit');
    }


    /**
     * Create customer account action
     */
    public function createPostAction()
    {
        /** @var $session Mage_Customer_Model_Session */
        $session = $this->_getSession();
        if ($session->isLoggedIn()) {
            $this->_redirect('*/*/');
            return;
        }
        $session->setEscapeMessages(true); // prevent XSS injection in user input
        if (!$this->getRequest()->isPost()) {
            $errUrl = $this->_getUrl('*/*/create', array('_secure' => true));
            $this->_redirectError($errUrl);
            return;
        }

        $customer = $this->_getCustomer();
        $customer->setData('is_lector',0);

        try {
            $errors = $this->_getCustomerErrors($customer);

            if (empty($errors)) {
                $customer->save();
                $this->_dispatchRegisterSuccess($customer);
                $this->_successProcessRegistration($customer);
                return;
            } else {
                $this->_addSessionError($errors);
            }
        } catch (Mage_Core_Exception $e) {
            $session->setCustomerFormData($this->getRequest()->getPost());
            if ($e->getCode() === Mage_Customer_Model_Customer::EXCEPTION_EMAIL_EXISTS) {
                $url = $this->_getUrl('customer/account/forgotpassword');
                $message = $this->__('There is already an account with this email address. If you are sure that it is your email address, <a href="%s">click here</a> to get your password and access your account.', $url);
                $session->setEscapeMessages(false);
            } else {
                $message = $e->getMessage();
            }
            $session->addError($message);
        } catch (Exception $e) {
            $session->setCustomerFormData($this->getRequest()->getPost())
                ->addException($e, $this->__('Cannot save the customer.'));
        }
        $errUrl = $this->_getUrl('*/*/create', array('_secure' => true));
        $this->_redirectError($errUrl);
    }

    public function refuseAction()
    {
        $customer = $this->_getSession()->getCustomer();
        if(!$customer->is_lector){
            $this->_redirect('*/*/');
            return;
        }
        /** @var Dentalex_Speakers_Model_Resource_Speaker_Product $collection */
        $collection =Mage::getResourceModel('dentalex_speakers/speaker_product');
        if(!$collection->refuseSpeakerProduct($customer->speaker_id,(int)$this->getRequest()->getParam('id')))
            $this->_getSession()->addError('This course not found!');
        $this->_getSession()->addSuccess('Success!');
        $this->_redirect('*/*/edit');
    }
}
				