<?php

class Softjourn_Course_Block_Catalog_Layer_View extends Mage_Catalog_Block_Layer_View
{
    const FILTERS_POSITION = 5;
    const CREDITS_ATTRIBUTE_CODE = 'credits';
    const START_DUIRATION_ATTRIBUTE_CODE = 'start_course';
    const END_DUIRATION_ATTRIBUTE_CODE = 'end_course';
    const SPEAKER_ATTRIBUTE_CODE = 'fullname';


    /**
     * State block name
     *
     * @var string
     */
    protected $_creditsBlockName;
    protected $_durationBlockName;

    protected function _initBlocks()
    {
        parent::_initBlocks();

        $this->_creditsBlockName = 'softjourn_course/catalog_layer_filter_credits';
        $this->_durationBlockName = 'softjourn_course/catalog_layer_filter_duration';
        $this->_speakerBlockName = 'softjourn_course/catalog_layer_filter_speaker';
    }

    /**
     * Prepare child blocks
     *
     * @return Mage_Catalog_Block_Layer_View
     */
    protected function _prepareLayout()
    {
        $attribute = Mage::getModel('eav/entity_attribute')
            ->loadByCode('catalog_product', self::CREDITS_ATTRIBUTE_CODE);

        $creditBlock = $this->getLayout()->createBlock($this->_creditsBlockName)
            ->setLayer($this->getLayer())
            ->setAttributeModel($attribute)
            ->init();

        $attribute = new stdClass();
        $attribute->start =   Mage::getModel('eav/entity_attribute')
            ->loadByCode('catalog_product', self::START_DUIRATION_ATTRIBUTE_CODE);
        $attribute->end =   Mage::getModel('eav/entity_attribute')
            ->loadByCode('catalog_product', self::END_DUIRATION_ATTRIBUTE_CODE);

        $durationBlock = $this->getLayout()->createBlock($this->_durationBlockName)
            ->setLayer($this->getLayer())
            ->setAttributeModel($attribute)
            ->init();

        $attribute = Mage::getModel('eav/entity_attribute')
            ->loadByCode('dentalex_speakers_speaker', self::SPEAKER_ATTRIBUTE_CODE);

        $speakerBlock = $this->getLayout()->createBlock($this->_speakerBlockName)
            ->setLayer($this->getLayer())
            ->setAttributeModel($attribute)
            ->init();

        $this->setChild('credits_filter', $creditBlock);
        $this->setChild('duration_filter', $durationBlock);
        $this->setChild('speaker_filter', $speakerBlock);

        return parent::_prepareLayout();
    }

    public function getFilters()
    {
        $filters = parent::getFilters();

        if (($myFilters = $this->_getFilters())) {
            // Insert credits filter to the self::CREDITS_FILTER_POSITION position
            $filters = array_merge(
                array_slice(
                    $filters,
                    0,
                    self::FILTERS_POSITION - 1
                ),
                $myFilters,
                array_slice(
                    $filters,
                    self::FILTERS_POSITION - 1,
                    count($filters) - 1
                )
            );
        }

        return $filters;
    }

    /**
     * Get filter blocks
     *
     * @return array
     */
    protected function _getFilters()
    {
        return array(
            $this->getChild('credits_filter'),
            $this->getChild('speaker_filter'),
            $this->getChild('duration_filter')
        );
    }


}
