<?php

class Softjourn_Course_Model_Catalog_Layer_Filter_Duration extends Mage_Catalog_Model_Layer_Filter_Abstract
{

    // day, weekend,  week, continuous, multiple weekends, long term learning, on your own time
    public $TIME_RANGE = array(
        1 => array(
           'label' => 'on your own time',
           'range' => array( 'from' => null, 'to'=> null ),
        ),
        86400 => array(
           'label' => 'one day',
           'range' => array( 'from' => null, 'to'=>86400 ),
        ),
        172800 => array(
           'label' => 'weekend',
           'range' => array( 'from' => 86400, 'to'=> 172800 ),
        ),
        604800 => array(
           'label' => 'week',
           'range' => array( 'from' => 172800, 'to'=> 604800 ),
        ),
        2505600 => array(
           'label' => 'multiple weekends',
           'range' => array( 'from' => 604800, 'to'=> 2505600 ),
        ),
        2592000 => array(
           'label' => 'long term learning, on your own time',
           'range' => array( 'from' => 1209600, 'to'=> null ),
        ),

    );

    /**
     * Get filter name
     *
     * @return string
     */
    public function getName()
    {
        return Mage::helper('softjourn_course')->__('Duration');
    }

    /**
     * Set attribute model to filter
     *
     * @param   stdClass $attribute
     * @return  Mage_Catalog_Model_Layer_Filter_Abstract
     */
    public function setAttributeModel($attribute)
    {
        $this->setRequestVar('duration');
        $this->setData('attribute_model', $attribute);
        return $this;
    }


    /**
     * Retrieve resource instance
     *
     * @return Softjourn_Course_Model_Resource_Layer_Filter_Duration
     */
    protected function _getResource()
    {
        if (is_null($this->_resource)) {
            $this->_resource = Mage::getResourceModel('softjourn_course/layer_filter_duration');
        }
        return $this->_resource;
    }

    /**
     * Prepare text of item label
     *
     * @param   int $index
     * @return  string
     */
    protected function _renderItemLabel($index)
    {
        return Mage::helper('softjourn_course')->__($this->TIME_RANGE[$index]['label']);
    }

    /**
     * Apply decimal range filter to product collection
     *
     * @param Zend_Controller_Request_Abstract $request
     * @param Mage_Catalog_Block_Layer_Filter_Decimal $filterBlock
     * @return Mage_Catalog_Model_Layer_Filter_Decimal
     */
    public function apply(Zend_Controller_Request_Abstract $request, $filterBlock)
    {
        parent::apply($request, $filterBlock);

        $this->_getResource()->outstandingToCollection($this);

        /**
         * Filter must be string: $index, $range
         */
        $filter = $request->getParam($this->getRequestVar());
        if (!$filter) {
            return $this;
        }


        if (empty($filter)) {
            return $this;
        }

        if ((int)$filter) {

            $this->_getResource()->applyFilterToCollection($this, $filter);
            $this->getLayer()->getState()->addFilter(
                $this->_createItem($this->_renderItemLabel($filter), $filter)
            );

            $this->_items = array();
        }

        return $this;
    }

    /**
     * Retrieve price aggreagation data cache key
     *
     * @return string
     */
    protected function _getCacheKey()
    {
        $key = $this->getLayer()->getStateKey()
            . '_ATTR_DURATION';
        return $key;
    }


    /**
     * Retrieve maximum value from layer products set
     *
     * @return float
     */
    public function getMaxValue()
    {
        $max = $this->getData('max_value');
        if (is_null($max)) {
            list($min, $max) = $this->_getResource()->getMinMax($this);
            $this->setData('max_value', $max);
            $this->setData('min_value', $min);
        }
        return $max;
    }

    /**
     * Retrieve minimal value from layer products set
     *
     * @return float
     */
    public function getMinValue()
    {
        $min = $this->getData('min_value');
        if (is_null($min)) {
            list($min, $max) = $this->_getResource()->getMinMax($this);
            $this->setData('max_value', $max);
            $this->setData('min_value', $min);
        }
        return $min;
    }


    /**
     * Retrieve information about products count in range
     *
     * @return int
     */
    public function getRangeItemCounts()
    {
        $rangeKey = 'range_item_counts';
        $items = $this->getData($rangeKey);
        if (is_null($items)) {
            $items = $this->_getResource()->getCount($this);
            $this->setData($rangeKey, $items);
        }
        return $items;
    }

    /**
     * Retrieve data for build decimal filter items
     *
     * @return array
     */
    protected function _getItemsData()
    {
        $key = $this->_getCacheKey();

        $data = $this->getLayer()->getAggregator()->getCacheData($key);
        if ($data === null) {
            $data       = array();

            $dbRanges   = $this->getRangeItemCounts();

            foreach ($dbRanges as $index => $count) {
                $data[] = array(
                    'label' => $this->_renderItemLabel($index),
                    'value' => $index,
                    'count' => $count,
                );
            }
        }
        return $data;
    }

}
