<?php

class Softjourn_Course_Model_Catalog_Layer_Filter_Speaker extends Mage_Catalog_Model_Layer_Filter_Abstract
{

    /**
     * Get filter name
     *
     * @return string
     */
    public function getName()
    {
        return Mage::helper('softjourn_course')->__('Speaker');
    }

    /**
     * Set attribute model to filter
     *
     * @param   stdClass $attribute
     * @return  Mage_Catalog_Model_Layer_Filter_Abstract
     */
    public function setAttributeModel($attribute)
    {
        $this->setRequestVar('speaker');
        $this->setData('attribute_model', $attribute);
        return $this;
    }

    /**
     * Retrieve resource instance
     *
     * @return Softjourn_Course_Model_Resource_Layer_Filter_Speaker
     */
    protected function _getResource()
    {
        if (is_null($this->_resource)) {
            $this->_resource = Mage::getResourceModel('softjourn_course/layer_filter_speaker');
        }
        return $this->_resource;
    }

    /**
     * Prepare text of item label
     *
     * @param   int $id
     * @return  string
     */
    protected function _renderItemLabel($id)
    {
        $attribute = Mage::getModel('dentalex_speakers/speaker')
            ->setStoreId(Mage::app()->getStore()->getId())
            ->load($id);

        return $attribute->getFullname();
    }

    /**
     * Apply decimal range filter to product collection
     *
     * @param Zend_Controller_Request_Abstract $request
     * @param Mage_Catalog_Block_Layer_Filter_Decimal $filterBlock
     * @return Mage_Catalog_Model_Layer_Filter_Decimal
     */
    public function apply(Zend_Controller_Request_Abstract $request, $filterBlock)
    {
        parent::apply($request, $filterBlock);

        /**
         * Filter must be string: $index, $range
         */
        $filter = $request->getParam($this->getRequestVar());
        if (!$filter) {
            return $this;
        }


        if (empty($filter)) {
            return $this;
        }

        if ((int)$filter) {

            $this->_getResource()->applyFilterToCollection($this, $filter);
            $this->getLayer()->getState()->addFilter(
                $this->_createItem($this->_renderItemLabel($filter), $filter)
            );

            $this->_items = array();
        }

        return $this;
    }

    /**
     * Retrieve price aggreagation data cache key
     *
     * @return string
     */
    protected function _getCacheKey()
    {
        $key = $this->getLayer()->getStateKey()
            . '_ATTR_SPEAKER';
        return $key;
    }



    /**
     * Retrieve information about products count in range
     *
     * @return int
     */
    public function getRangeItemCounts()
    {
        $rangeKey = 'speaker_item_counts';
        $items = $this->getData($rangeKey);
        if (is_null($items)) {
            $items = $this->_getResource()->getCount($this);
            $this->setData($rangeKey, $items);
        }
        return $items;
    }

    /**
     * Retrieve data for build decimal filter items
     *
     * @return array
     */
    protected function _getItemsData()
    {
        $key = $this->_getCacheKey();

        $data = $this->getLayer()->getAggregator()->getCacheData($key);
        if ($data === null) {
            $data       = array();

            $dbRanges   = $this->getRangeItemCounts();

            foreach ($dbRanges as $index => $speaker) {
                $data[] = array(
                    'label' => $speaker['name'],
                    'value' => $speaker['speaker_id'],
                    'count' => $speaker['count'],
                );
            }

        }
        return $data;
    }

}
