<?php

class Softjourn_Course_Model_Catalog_Product_Option_Type_Person
    extends Mage_Catalog_Model_Product_Option_Type_Select
{
    public function isCustomizedView()
    {
        return false;
    }

    public function getCustomizedView($optionInfo)
    {
        $customizeBlock = new Softjourn_Course_Block_Options_Type_Customview_Person();
        $customizeBlock->setInfo($optionInfo);

        return $customizeBlock->toHtml();
    }


    /**
     * Validate user input for option
     *
     * @throws Mage_Core_Exception
     * @param array $values All product option values, i.e. array (option_id => mixed, option_id => mixed...)
     * @return Mage_Catalog_Model_Product_Option_Type_Default
     */
    public function validateUserValue($values)
    {
        Mage::getSingleton('checkout/session')->setUseNotice(false);

        $this->setIsValid(false);

        $option = $this->getOption();
        if (!isset($values[$option->getId()]) && $option->getIsRequire() && !$this->getSkipCheckRequiredOption()) {
            Mage::throwException(Mage::helper('catalog')->__('Please specify the product required option(s).'));
        } elseif (isset($values[$option->getId()])) {
            $this->setUserValue($values[$option->getId()]);
            $this->setIsValid(true);
        }

        $value = $this->getUserValue();
        if (empty($value) && $option->getIsRequire() && !$this->getSkipCheckRequiredOption()) {
            $this->setIsValid(false);
            Mage::throwException(Mage::helper('catalog')->__('Please specify the product required option(s).'));
        }

        return $this;
    }


    /**
     * Prepare option value for cart
     *
     * @throws Mage_Core_Exception
     * @return mixed Prepared option value
     */
    public function prepareForCart()
    {
        if ($this->getIsValid() && $this->getUserValue()) {
            $_values = array();
            foreach ($this->getUserValue() as $value => $count) {
                $_values[] = $value . ':' . $count;
            }

            return implode(',', $_values);
        } else {
            return null;
        }
    }


    /**
     * Return formatted option value ready to edit, ready to parse
     *
     * @param string $optionValue Prepared for cart option value
     * @return string
     */
    public function getEditableOptionValue($optionValue)
    {
        $option = $this->getOption();
        $result = '';

        foreach (explode(',', $optionValue) as $_valuePear) {
            list($_value, $_count) = explode(':', $_valuePear);

            if ($_result = $option->getValueById($_value)) {
                $result .= $_result->getTitle() . ': ' . $_count . ', ';
            } else {
                if ($this->getListener()) {
                    $this->getListener()
                        ->setHasError(true)
                        ->setMessage(
                            $this->_getWrongConfigurationMessage()
                        );
                    $result = '';
                    break;
                }
            }
        }
        $result = Mage::helper('core/string')->substr($result, 0, -2);

        return $result;
    }

    /**
     * Return Price for selected option
     *
     * @param string $optionValue Prepared for cart option value
     * @param float $basePrice
     * @return float
     */
    public function getOptionPrice($optionValue, $basePrice)
    {
        $option = $this->getOption();
        $result = 0;


        foreach (explode(',', $optionValue) as $value) {
            list($_value, $_count) = explode(':', $value);

            if ($_result = $option->getValueById($_value)) {
                $result += $this->_getChargableOptionPrice(
                    $_result->getPrice(),
                    $_result->getPriceType() == 'percent',
                    $basePrice,
                    $_count
                );
            } else {
                if ($this->getListener()) {
                    $this->getListener()
                        ->setHasError(true)
                        ->setMessage(
                            $this->_getWrongConfigurationMessage()
                        );
                    break;
                }
            }
        }


        return $result;
    }

    /**
     * Return SKU for selected option
     *
     * @param string $optionValue Prepared for cart option value
     * @param string $skuDelimiter Delimiter for Sku parts
     * @return string
     */
    public function getOptionSku($optionValue, $skuDelimiter)
    {
        $option = $this->getOption();

        $skus = array();
        foreach (explode(',', $optionValue) as $value) {
            list($_value, $_count) = explode(':', $value);

            if ($optionSku = $option->getValueById($_value)) {
                $skus[] = $optionSku->getSku();
            } else {
                if ($this->getListener()) {
                    $this->getListener()
                        ->setHasError(true)
                        ->setMessage(
                            $this->_getWrongConfigurationMessage()
                        );
                    break;
                }
            }
        }
        $result = implode($skuDelimiter, $skus);


        return $result;
    }


    /**
     * Return final chargable price for option
     *
     * @param float $price Price of option
     * @param boolean $isPercent Price type - percent or fixed
     * @param float $basePrice For percent price type
     * @param int $count Count of option selected
     * @return float
     */
    protected function _getChargableOptionPrice($price, $isPercent, $basePrice, $count = 1)
    {
        if ($isPercent) {
            return ($basePrice * $price / 100) * $count;
        } else {
            return $price * $count;
        }
    }


}