<?php

class Softjourn_Course_Model_Resource_Layer_Filter_Duration extends Mage_Core_Model_Resource_Db_Abstract
{
    const START_IDX_ALIAS = 'start_course_idx';
    const END_IDX_ALIAS = 'end_course_idx';

    /**
     * Initialize connection and define main table name
     *
     */
    protected function _construct()
    {
        $this->_init('softjourn_course/catalog_product_entity_datetime', 'entity_id');
    }

    /**
     * Apply outstanding filter to product collection
     *
     * @param Softjourn_Course_Model_Catalog_Layer_Filter_Duration $filter
     * @return Softjourn_Course_Model_Resource_Layer_Filter_Duration
     */
    public function outstandingToCollection($filter)
    {
        $collection = $filter->getLayer()->getProductCollection();

        $connection = $this->_getReadAdapter();

        $endTableAlias = 'end_course_1_idx';
        $conditions = array(
            "{$endTableAlias}.entity_id = e.entity_id",
            "({$endTableAlias}.value > NOW() OR {$endTableAlias}.value IS NULL)",
            $connection->quoteInto("{$endTableAlias}.attribute_id = ?", $filter->getAttributeModel()->end->getId())
        );

        $collection->getSelect()->join(
            array($endTableAlias => $this->getMainTable()),
            implode(' AND ', $conditions),
            array()
        );

        $collection->getSelect()->distinct();


    }

    /**
     * Apply attribute filter to product collection
     *
     * @param Softjourn_Course_Model_Catalog_Layer_Filter_Duration $filter
     * @param int $index
     * @return Softjourn_Course_Model_Resource_Layer_Filter_Duration
     */
    public function applyFilterToCollection($filter, $index)
    {
        $collection = $filter->getLayer()->getProductCollection();

        $connection = $this->_getReadAdapter();

        $startTableAlias = self::START_IDX_ALIAS;
        $conditions = array(
            "{$startTableAlias}.entity_id = e.entity_id",
//            "{$startTableAlias}.value > NOW()",
            $connection->quoteInto("{$startTableAlias}.attribute_id = ?", $filter->getAttributeModel()->start->getId())
        );

        $collection->getSelect()->join(
            array($startTableAlias => $this->getMainTable()),
            implode(' AND ', $conditions),
            array()
        );


        $endTableAlias = 'end_course_idx';
        $conditions = array(
            "{$endTableAlias}.entity_id = e.entity_id",
            "({$endTableAlias}.value > NOW() OR {$endTableAlias}.value IS NULL)",
            $connection->quoteInto("{$endTableAlias}.attribute_id = ?", $filter->getAttributeModel()->end->getId())
        );

        $collection->getSelect()->join(
            array($endTableAlias => $this->getMainTable()),
            implode(' AND ', $conditions),
            array()
        );

        if( $filter->TIME_RANGE[$index]['range']['from'] !== null )
            $collection->getSelect()
                ->where("{$endTableAlias}.value - {$startTableAlias}.value >= ?", $filter->TIME_RANGE[$index]['range']['from'] );

        if( $filter->TIME_RANGE[$index]['range']['to'] !== null )
            $collection->getSelect()
                ->where("{$endTableAlias}.value - {$startTableAlias}.value < ?", $filter->TIME_RANGE[$index]['range']['to']);

        return $this;
    }

    /**
     * Retrieve array of minimal and maximal values
     *
     * @param Softjourn_Course_Model_Catalog_Layer_Filter_Duration $filter
     * @return array
     */
    public function getMinMax($filter)
    {
        $select = $this->_getSelect($filter);
        $adapter = $this->_getReadAdapter();

        $select->columns(array(
            'min_value' => new Zend_Db_Expr('MIN( '. self::END_IDX_ALIAS .'.value - '. self::START_IDX_ALIAS .'.value)'),
            'max_value' => new Zend_Db_Expr('MAX('. self::END_IDX_ALIAS .'.value - '. self::START_IDX_ALIAS .'.value)'),
        ));

        $result = $adapter->fetchRow($select);

        return array($result['min_value'], $result['max_value']);
    }

    /**
     * Retrieve clean select with joined index table
     * Joined table has index
     *
     * @param Softjourn_Course_Model_Catalog_Layer_Filter_Duration $filter
     * @return Varien_Db_Select
     */
    protected function _getSelect($filter)
    {
        $collection = $filter->getLayer()->getProductCollection();

        // clone select from collection with filters
        $select = clone $collection->getSelect();
        // reset columns, order and limitation conditions
        $select->reset(Zend_Db_Select::COLUMNS);
        $select->reset(Zend_Db_Select::ORDER);
        $select->reset(Zend_Db_Select::LIMIT_COUNT);
        $select->reset(Zend_Db_Select::LIMIT_OFFSET);

//        $storeId = $collection->getStoreId();

        $attributeId = $filter->getAttributeModel()->start->getId();
        $select->join(
            array(self::START_IDX_ALIAS => $this->getMainTable()),
            'e.entity_id = ' . self::START_IDX_ALIAS . '.entity_id ' .
            ' AND ' . $this->_getReadAdapter()->quoteInto(self::START_IDX_ALIAS . '.attribute_id = ?', $attributeId),
        //TODO:: hard code according to magento bug, not save store_id in catalog_product_entity_datetime table
//            ' AND ' . $this->_getReadAdapter()->quoteInto(self::START_IDX_ALIAS . '.store_id = ?', $storeId),
            array()
        );

        $attributeId = $filter->getAttributeModel()->end->getId();
        $select->join(
            array(self::END_IDX_ALIAS => $this->getMainTable()),
            'e.entity_id = ' . self::END_IDX_ALIAS . '.entity_id ' .
            ' AND ( '.self::END_IDX_ALIAS. '.value > NOW() OR '.self::END_IDX_ALIAS. '.value IS NULL) '.
            ' AND ' . $this->_getReadAdapter()->quoteInto(self::END_IDX_ALIAS . '.attribute_id = ?', $attributeId),
//            ' AND ' . $this->_getReadAdapter()->quoteInto(self::END_IDX_ALIAS . '.store_id = ?', $storeId),
            array()
        );

        return $select;
    }

    /**
     * Retrieve array with products counts per range
     *
     * @param Softjourn_Course_Model_Catalog_Layer_Filter_Duration $filter
     * @return array
     */
    public function getCount($filter)
    {
        $select = $this->_getSelect($filter);
        $adapter = $this->_getReadAdapter();

        $rangeCondition = ' (CASE ';

        foreach($filter->TIME_RANGE as $key => $info) {

            $firstRangeCondition = ' WHEN  '. self::END_IDX_ALIAS .'.value - '. self::START_IDX_ALIAS .'.value  ';

            if(  $info['range']['from'] === null && $info['range']['to'] === null) {
                $rangeCondition .= ' WHEN ' . self::END_IDX_ALIAS . '.value IS NULL OR ' . self::START_IDX_ALIAS . '.value IS NULL ';
            }elseif( $info['range']['from'] === null){
                $rangeCondition .= $firstRangeCondition. ' <= '. $info['range']['to'];
            }elseif($info['range']['to'] === null){
                $rangeCondition .= $firstRangeCondition. ' >= '.  $info['range']['from'];
            }else{
                $rangeCondition .= $firstRangeCondition. 'BETWEEN '. $info['range']['from'] .' and '. $info['range']['to'];
            }

            $rangeCondition .= ' THEN '. $key;
        }


        $rangeCondition .= ' END) ';

        $countExpr = new Zend_Db_Expr("COUNT(*)");
        $rangeExpr = new Zend_Db_Expr($rangeCondition);

        $select->columns(array(
            'range' => $rangeExpr,
            'count' => $countExpr
        ));
        $select->group('range');

        return $adapter->fetchPairs($select);
    }
}
