<?php

class Softjourn_Course_Model_Resource_Layer_Filter_Speaker extends Mage_Core_Model_Resource_Db_Abstract
{

    const SPEAKER_COUNT = 10;

    /**
     * Initialize connection and define main table name
     *
     */
    protected function _construct()
    {
        $this->_init('softjourn_course/dentalex_speakers_speaker_product', 'entity_id');
    }

    /**
     * Apply attribute filter to product collection
     *
     * @param Softjourn_Course_Model_Catalog_Layer_Filter_Duration $filter
     * @param int $index
     * @return Softjourn_Course_Model_Resource_Layer_Filter_Duration
     */
    public function applyFilterToCollection($filter, $index)
    {
        $collection = $filter->getLayer()->getProductCollection();

        $connection = $this->_getReadAdapter();

        $tableAlias = 'speaker_idx';
        $collection->getSelect()->join(
            array($tableAlias => $this->getMainTable()),
            'e.entity_id = ' . $tableAlias.'.product_id ',
            array()
        );

        $collection->getSelect()->join(
            array('speaker_varchar_idx' => 'dentalex_speakers_speaker_varchar'),
            $connection->quoteInto($tableAlias.'.speaker_id = speaker_varchar_idx.entity_id AND speaker_varchar_idx.attribute_id = ?',
                $filter->getAttributeModel()->getId()
            ),
            array()
        );

        $collection->getSelect()
            ->where(" {$tableAlias}.speaker_id = ?", $index);

        return $this;
    }


    /**
     * Retrieve clean select with joined index table
     * Joined table has index
     *
     * @param Softjourn_Course_Model_Catalog_Layer_Filter_Speaker $filter
     * @return Varien_Db_Select
     */
    protected function _getSelect($filter)
    {
        $collection = $filter->getLayer()->getProductCollection();
        $connection = $this->_getReadAdapter();

        // clone select from collection with filters
        $select = clone $collection->getSelect();
        // reset columns, order and limitation conditions
        $select->reset(Zend_Db_Select::COLUMNS);
        $select->reset(Zend_Db_Select::ORDER);
        $select->reset(Zend_Db_Select::LIMIT_COUNT);
        $select->reset(Zend_Db_Select::LIMIT_OFFSET);

        $select->join(
            array('spk' => $this->getMainTable()),
            'e.entity_id = ' . 'spk.product_id ',
            array()
        );

        $select->join(
            array('spk_varchar' => 'dentalex_speakers_speaker_varchar'),
            $connection->quoteInto('spk.speaker_id = spk_varchar.entity_id AND spk_varchar.attribute_id = ?',
                $filter->getAttributeModel()->getId()
            ),
            array()
        );

        $select->joinLeft(
            array('review_summary' => 'review_entity_summary'),
            'review_summary.entity_pk_value = e.entity_id AND review_summary.entity_type = 1',
            array()
        );
        //CREATE TABLE review_entity_summary
//        (
//        primary_id BIGINT PRIMARY KEY NOT NULL AUTO_INCREMENT,
//    entity_pk_value BIGINT DEFAULT 0 NOT NULL,
//    entity_type SMALLINT DEFAULT 0 NOT NULL,
//    reviews_count SMALLINT DEFAULT 0 NOT NULL,
//    rating_summary SMALLINT DEFAULT 0 NOT NULL,
//    store_id SMALLINT UNSIGNED DEFAULT 0 NOT NULL
//);
//CREATE INDEX IDX_REVIEW_ENTITY_SUMMARY_STORE_ID ON review_entity_summary (store_id);


        return $select;
    }

    /**
     * Retrieve array with products counts
     *
     * @param Softjourn_Course_Model_Catalog_Layer_Filter_Speaker $filter
     * @return array
     */
    public function getCount($filter)
    {
        $select = $this->_getSelect($filter);
        $adapter = $this->_getReadAdapter();

        $countExpr = new Zend_Db_Expr("COUNT(*)");

        $select->columns(array(
            'speaker_id' => 'spk.speaker_id',
            'name' => 'spk_varchar.value',
            'count' => $countExpr
        ));

        $select->order('review_summary.rating_summary DESC');
        $select->group('speaker_id');
        $select->limit(self::SPEAKER_COUNT);

        return $adapter->fetchAll($select);
    }
}
