function initialize() {

    var geocoder = new google.maps.Geocoder();

    var lat = 46.774876, lon = -71.231590;
    var point = document.getElementById('geo_map').value;

    if (point) {
        lat = point.split(',')[0];
        lon = point.split(',')[1];
    }

    var input = /** @type {HTMLInputElement} */(document.getElementById('pac-input'));
    //var types = document.getElementById('type-selector');

    var location = new google.maps.LatLng(lat, lon);
    var mapOptions = {
        center: location,
        zoom: 8,
        mapTypeControl: false,
        draggable: true,
        scaleControl: true,
        scrollwheel: true,
        navigationControl: false,
        streetViewControl: false,
        mapTypeId: google.maps.MapTypeId.ROADMAP
    };

    var map = new google.maps.Map(document.getElementById('geo-map-canvas'), mapOptions);

    map.controls[google.maps.ControlPosition.TOP_LEFT].push(input);
    //map.controls[google.maps.ControlPosition.TOP_LEFT].push(types);

    var autocomplete = new google.maps.places.Autocomplete(input);
    autocomplete.bindTo('bounds', map);

    var marker = new google.maps.Marker({
        map: map,
        position: location,
        draggable: true,
        anchorPoint: new google.maps.Point(0, -29)
    });

    google.maps.event.addListener(autocomplete, 'place_changed', function () {
        marker.setVisible(false);

        var place = autocomplete.getPlace();
        if (!place.geometry) {
            return;
        }

        if (place.geometry.viewport) {
            map.fitBounds(place.geometry.viewport);
        } else {
            map.setCenter(place.geometry.location);
            map.setZoom(17);  // Why 17? Because it looks good.
        }

        marker.setIcon(/** @type {google.maps.Icon} */({
            url: place.icon,
            size: new google.maps.Size(71, 71),
            origin: new google.maps.Point(0, 0),
            anchor: new google.maps.Point(17, 34),
            scaledSize: new google.maps.Size(35, 35)
        }));


        marker.setPosition(place.geometry.location);
        marker.setVisible(true);


        if (place.address_components) {
            setLocationAddress( place.address_components);
        }

        lat = place.geometry.location.lat();
        lon = place.geometry.location.lng();

        document.getElementById('geo_map').value = lat + ',' + lon;
    });


    google.maps.event.addListener(marker, 'dragend', function () {
        geocodePosition(marker.getPosition());

        lat = marker.position.lat();
        lon = marker.position.lng();

        document.getElementById('geo_map').value = lat + ',' + lon;

    });

    // Sets a listener on a radio button to change the filter type on Places
    // Autocomplete.
    function setupClickListener(id, types) {
        var radioButton = document.getElementById(id);
        google.maps.event.addDomListener(radioButton, 'click', function() {
            autocomplete.setTypes(types);
        });
    }

    //setupClickListener('changetype-all', []);
    //setupClickListener('changetype-address', ['address']);
    //setupClickListener('changetype-establishment', ['establishment']);
    //setupClickListener('changetype-geocode', ['geocode']);

    function setLocationAddress(arrAddress){

        document.getElementById("geo_street").value = '';
        document.getElementById("geo_postcode").value = '';
        document.getElementById("geo_region").value = '';
        document.getElementById("geo_city").value = '';

        for (var ac = 0; ac < arrAddress.length; ac++) {
            //if (arrAddress[ac].types[0] == "street_number") { document.getElementById("tbUnit").value = arrAddress[ac].long_name }
            if (arrAddress[ac].types[0] == "route") {
                document.getElementById("geo_street").value = arrAddress[ac].short_name
            }

            if (arrAddress[ac].types[0] == "locality") {
                document.getElementById("geo_city").value = arrAddress[ac].long_name
            }
            if (arrAddress[ac].types[0] == "administrative_area_level_1") {
                document.getElementById("geo_region").value = arrAddress[ac].short_name
            }
            if (arrAddress[ac].types[0] == "postal_code") {
                document.getElementById("geo_postcode").value = arrAddress[ac].long_name
            }
            if (arrAddress[ac].types[0] == "country") {
                var country = arrAddress[ac].short_name;

                $$('select#geo_country_id option').each(function (o) {
                    o.selected = o.readAttribute('value') == country;
                });
            }
        }
    }

    function geocodePosition(pos) {
        geocoder.geocode({
            latLng: pos
        }, function(responses) {
            if (responses && responses.length > 0) {
                setLocationAddress(responses[0].address_components);
            } else {
                setLocationAddress([]);
            }
        });
    }
}


jQuery(document).ready(function () {
    jQuery('#product_info_tabs_group_34').click(function () {
        initialize();
    });
});

google.maps.event.addDomListener(window, 'load', initialize);